@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "AcquireStmt.h"
@@ -44,29 +48,29 @@ void AcquireStmt::EmitActual(Bytecode &b)
 	RCX_Cmd cmd;
 	int handlerLabel = b.NewLabel();
 	int endLabel = b.NewLabel();
-	
-	// start event monitoring	
-	cmd.Set(0x73, fResources, 0, 0);
+
+	// start event monitoring
+	cmd.Set(kRCX_EnterAccessCtrlOp, fResources, 0, 0);
 	b.Add(cmd);
 	b.AddFixup(Bytecode::kSignBitLongFixup, handlerLabel);
-	
+
 	GetPrimary()->Emit(b);
-	
+
 	// end event monitoring
-	cmd.Set(0xa0);
+	cmd.Set(kRCX_ExitAccessCtrlOp);
 	b.Add(cmd);
-	
+
 	if (GetSecondary())
 		b.AddJump(endLabel);
-	
+
 	// here's the handler
 	b.SetLabel(handlerLabel);
 
 	if (GetSecondary())
 		GetSecondary()->Emit(b);
-		
+
 	b.SetLabel(endLabel);
-	
+
 	b.EndHandler(Bytecode::kAcquireHandler);
 }
 
