@@ -12,9 +12,13 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 2000 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
-#include <string.h>
+#include <cstring>
 #include "AssignMathStmt.h"
 #include "RCX_Cmd.h"
 #include "Bytecode.h"
@@ -36,11 +40,14 @@ void AssignMathStmt::EmitActual(Bytecode &b)
 	{
 		EmitOperation(b, RCX_VALUE_DATA(dst));
 	}
-	else
-	{
-		Error(kErr_NotSupported, "math assignment to non-vars").Raise(&fLval->GetLoc());
-	}
-	
+	else if (b.GetTarget()->fHasExtendedMathOps && (fCode != kRCX_IllegalVar))
+        {
+                // this firmware supports math assignment to generic sources
+                EmitValueOperation(b, dst);
+        }
+        else
+            Error(kErr_NotSupported, "math assignment to non-vars").Raise(&fLval->GetLoc());
+
 	b.ReleaseTempEA(dst);
 }
 
@@ -58,6 +65,18 @@ void AssignMathStmt::EmitOperation(Bytecode &b, int var)
 	}
 }
 
+void AssignMathStmt::EmitValueOperation(Bytecode &b, RCX_Value dst)
+{
+        RCX_Value ea = fValue->EmitMath(b);
+        if (ea != Expr::kIllegalEA)
+        {
+            RCX_Cmd cmd;
+            cmd.MakeSetMath(dst, ea, fCode);
+            b.Add(cmd);
+            b.ReleaseTempEA(ea);
+        }
+}
+
 
 Stmt* AssignMathStmt::CloneActual(Mapping *m) const
 {
