@@ -12,9 +12,13 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
-#include <string.h>
+#include <cstring>
 #include "AssignStmt.h"
 #include "RCX_Cmd.h"
 #include "Bytecode.h"
@@ -40,10 +44,10 @@ void AssignStmt::EmitActual(Bytecode &b)
 {
 	RCX_Value dst = fLval->EmitAny(b);
 	int type = RCX_VALUE_TYPE(dst);
-	
-	if (type == kRCX_VariableType)
+
+ 	if (type == kRCX_VariableType)
 	{
-		fValue->EmitTo(b, RCX_VALUE_DATA(dst));
+                fValue->EmitTo(b, RCX_VALUE_DATA(dst));
 	}
 	else
 	{
@@ -51,17 +55,17 @@ void AssignStmt::EmitActual(Bytecode &b)
 		{
 			RCX_Cmd cmd;
 			RCX_Value ea = fValue->EmitAny(b);
-			
+
 			cmd.MakeSet(dst, ea);
 			b.Add(cmd);
-			
-			b.ReleaseTempEA(ea); 
+
+			b.ReleaseTempEA(ea);
 		}
 		else
 			Error(kErr_LValueNeeded).Raise(&fLval->GetLoc());
-		
+
 	}
-	
+
 	b.ReleaseTempEA(dst); // ea may be an array with temp index
 }
 
