@@ -12,25 +12,31 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __AutoFree_h
 #define __AutoFree_h
 
-#include <stddef.h>
+#include <cstddef>
+
+using std::size_t;
 
 class AutoFreeGroup
 {
 public:
 			AutoFreeGroup();
-	
+
 	// these are called by new/delete operators
 	void*	allocate(size_t);
 	void	free(void*);
-	
+
 	// call this to release all remaining objects
 	void	freeAll();
-	
+
 private:
 	struct Link
 	{
@@ -40,7 +46,7 @@ private:
 
 	// internal call to unlink and dispose an item
 	void	dispose(Link *link);
-	
+
 
 	Link head_;
 	Link tail_;
