@@ -12,18 +12,24 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "BinaryExpr.h"
 #include "parser.h"
 #include "Bytecode.h"
 #include "RCX_Cmd.h"
+#include "Program.h"
 
 
 static RCX_VarCode GetBinaryCode(int op);
 
 static RCX_VarCode GetBinaryCode(int op)
 {
+        const RCX_Target *t = gProgram->GetTarget();
 	switch(op)
 	{
 		case '+':
@@ -38,6 +44,26 @@ static RCX_VarCode GetBinaryCode(int op)
 			return kRCX_AndVar;
 		case '|':
 			return kRCX_OrVar;
+		case '%':
+			if (t->fType == kRCX_SwanTarget)
+				return kRCX_ModVar;
+			else
+				return kRCX_IllegalVar;
+		case LEFT:
+			if (t->fType == kRCX_SwanTarget)
+				return kRCX_ShlVar;
+			else
+				return kRCX_IllegalVar;
+		case RIGHT:
+			if (t->fType == kRCX_SwanTarget)
+				return kRCX_ShrVar;
+			else
+				return kRCX_IllegalVar;
+		case '^':
+			if (t->fType == kRCX_SwanTarget)
+				return kRCX_XOrVar;
+			else
+				return kRCX_IllegalVar;
 		default:
 			return kRCX_IllegalVar;
 	}
@@ -60,10 +86,10 @@ Expr* BinaryExpr::Clone(Mapping *b) const
 bool BinaryExpr::Evaluate(int &value) const
 {
 	int v1, v2;
-	
+
 	if (!Get(0)->Evaluate(v1)) return false;
 	if (!Get(1)->Evaluate(v2)) return false;
-	
+
 	switch(fOp)
 	{
 		case '+':
@@ -106,12 +132,12 @@ bool BinaryExpr::Evaluate(int &value) const
 
 RCX_Value BinaryExpr::EmitAny_(Bytecode &b) const
 {
-	RCX_Cmd cmd;	
+	RCX_Cmd cmd;
 	RCX_Value ea;
 	RCX_Value dstEA;
 	int dst;
 	RCX_VarCode code;
-	
+
 	ea = Get(0)->EmitAny(b);
 	if (ea == kIllegalEA) return ea;
 
@@ -122,10 +148,10 @@ RCX_Value BinaryExpr::EmitAny_(Bytecode &b) const
 		dst = GetTempVar(b);
 		if (dst < 0)
 			return kIllegalEA;
-		
+
 		b.AddMove(dst, ea);
 	}
-	
+
 	code = GetBinaryCode(fOp);
 	dstEA = RCX_VALUE(kRCX_VariableType, dst);
 	ea = Get(1)->EmitMath(b);
@@ -138,7 +164,7 @@ RCX_Value BinaryExpr::EmitAny_(Bytecode &b) const
 	cmd.MakeVar(code, dst, ea);
 	b.Add(cmd);
 	b.ReleaseTempEA(ea);
-	
+
 	return dstEA;
 }
 
@@ -150,20 +176,20 @@ bool BinaryExpr::EmitTo_(Bytecode &b, int dst) const
 	else
 	{
 		Get(0)->EmitTo(b, dst);
-		
+
 		RCX_Cmd cmd;
-		RCX_VarCode	code = GetBinaryCode(fOp);
+		RCX_VarCode code = GetBinaryCode(fOp);
 		RCX_Value ea = Get(1)->EmitMath(b);
 		if (ea == kIllegalEA) return false;
-		
+
 		cmd.MakeVar(code, dst, ea);
 		b.Add(cmd);
 		b.ReleaseTempEA(ea);
-		return true;					
+		return true;
 	}
 }
 
 bool BinaryExpr::NeedsConstant(int op)
 {
-	return GetBinaryCode(op) == kRCX_IllegalVar; 
+	return GetBinaryCode(op) == kRCX_IllegalVar;
 }
