@@ -12,10 +12,15 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef _STDIO_H
-#include <stdio.h>
+#include <cstdio>
+using std::FILE;
 #endif
 
 class Buffer
@@ -29,13 +34,16 @@ public:
 	void			Create(const char *name, const char *data, int length);
 
 	const char*		GetName() const		{ return fName; }
-	int				GetLength() const	{ return fLength; }	
+	int				GetLength() const	{ return fLength; }
 	const char *	GetData() const		{ return fData; }
 
 	const char *	GetLine(int line) const;
-	
+
 	int				FindLine(int &offset) const;
 
+	int				FindStartOfLine(int offset) const;
+	int				FindEndOfLine(int offset) const;
+
 protected:
 	void	FinishCreate(const char *name);
 	void	ConvertLineEndings();
