@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Bytecode_h
@@ -45,7 +49,9 @@
 #include "RCX_SourceTag.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class RCX_Cmd;
 
@@ -57,7 +63,7 @@ class RCX_Target;
 
 class Bytecode
 {
-public:	
+public:
 	enum HandlerCode
 	{
 		// codes for Handler contexts
@@ -65,7 +71,7 @@ public:
 		kAcquireHandler,
 		kHandlerCount	// not an actual handler - must be the last code
 	};
-	
+
 	enum FlowCode
 	{
 		// codes for Flow contexts
@@ -74,7 +80,7 @@ public:
 		kReturnFlow,
 		kFlowCount	// not an actual flow - must be the last code
 	};
-	
+
 	enum FixupCode
 	{
 		kNoFixup = 0, // used to invalidiate a fixup
@@ -83,13 +89,13 @@ public:
 		kSignBitLongFixup,
 		kSignBitShortFixup
 	};
-	
-				Bytecode(VarAllocator &varAllocator, const RCX_Target *target, RCX_Image *image);
-				~Bytecode();
 
-	int				GetLength()	const	{ return fData.size(); }
+	Bytecode(VarAllocator &varAllocator, const RCX_Target *target, RCX_Image *image);
+	~Bytecode();
+
+	int		GetLength()	const	{ return fData.size(); }
 	const UByte*	GetData() const		{ return &fData[0]; }
-	
+
 	void		Add(const RCX_Cmd &cmd);
 	void		AddJump(int label);
 	void		AddTest(RCX_Value v1, RCX_Relation rel, RCX_Value v2, int label);
@@ -97,73 +103,73 @@ public:
 	void		Truncate(int length);
 
 	bool		AddFlowJump(FlowCode code);
-	
-	int			NewLabel();
+
+	int		NewLabel();
 	void		SetLabel(int label, int target = kCurrentPosition);
-	int			GetLabelPosition(int label) const { return fLabels[label]; }
+	int		GetLabelPosition(int label) const { return fLabels[label]; }
 	void		AddFixup(FixupCode code, int label, int opcodeOffset=0, UByte shortOpcode=0);
 	void		ApplyFixups();
 
-	int			PushFlow(FlowCode code, bool legal=true);
+	int		PushFlow(FlowCode code, bool legal=true);
 	void		PopFlow(FlowCode code)		{ fFlowContexts[code].pop_back(); }
 
 	bool		BeginHandler(int type);
 	void		EndHandler(int type);
 
-	int			GetTempVar(bool canUseLocal);
+	int		GetTempVar(bool canUseLocal);
 	void		ReleaseTempEA(RCX_Value ea);
 	bool		IsTempEA(RCX_Value ea) const;
 	bool		IsLocalEA(RCX_Value ea) const;
-	
+
 	VarAllocator&	GetVarAllocator()	{ return fVarAllocator; }
-		
+
 	const RCX_Target*	GetTarget() const	{ return fTarget; }
-	
+
 	void		AddVariableName(int index, const char *name) { fImage->SetVariable(index, name); }
 
 	// source tags
-	void				AddSourceTag(int type, const LexLocation &loc);
+	void			AddSourceTag(int type, const LexLocation &loc);
 	const RCX_SourceTag*	GetSourceTags() const		{ return &fTags[0]; }
-	int					GetSourceTagCount() const	{ return fTags.size(); }
-	
+	int			GetSourceTagCount() const	{ return fTags.size(); }
+
 private:
 	class Fixup : public PLinkS<Fixup>
 	{
 	public:
 		FixupCode 	fType;
 		UShort		fLocation;
-		int			fLabel;
-		int			fOpcodeOffset;
-		int			fShortOpcode;
+		int		fLabel;
+		int		fOpcodeOffset;
+		int		fShortOpcode;
 	};
-		
+
 	struct HandlerContext
 	{
-				HandlerContext() : fInUse(false)	{ }
+		HandlerContext() : fInUse(false)	{ }
 
-		int		fFlowLevels[kFlowCount];
+		int	fFlowLevels[kFlowCount];
 		bool	fInUse;
 	};
 
-	int			GetFlowLevel(FlowCode code)	{ return fFlowContexts[code].size(); }
-	int			GetFlowLabel(FlowCode code);
+	int		GetFlowLevel(FlowCode code)	{ return fFlowContexts[code].size(); }
+	int		GetFlowLabel(FlowCode code);
 	void		Add(const UByte *data, int count);
 	void		AddHandlerExit(int i);
 	void		OptimizeFixups();
 	bool		ShortenFixup(Fixup &f);
 
-	vector<UByte>		fData;
+	vector<UByte>	fData;
 
-	PListSS<Fixup>		fFixups;
-	vector<UShort>		fLabels;
+	PListSS<Fixup>	fFixups;
+	vector<UShort>	fLabels;
 
-	vector<int>			fFlowContexts[kFlowCount];	
-	HandlerContext		fHandlerContexts[kHandlerCount];
+	vector<int>	fFlowContexts[kFlowCount];
+	HandlerContext	fHandlerContexts[kHandlerCount];
 
 	VarAllocator&		fVarAllocator;
 	const RCX_Target*	fTarget;
-	RCX_Image*			fImage; // used to hold symbolic information
-	
+	RCX_Image*		fImage; // used to hold symbolic information
+
 	// source info (used for mixed source/code listings
 	vector<RCX_SourceTag>	fTags;
 };
