@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __CallStmt_h
@@ -25,7 +29,9 @@
 #include "parser.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Symbol;
 class Expr;
@@ -35,7 +41,7 @@ class CallStmt : public ChainStmt
 public:
 			CallStmt();
 			~CallStmt();
-	
+
 	void		EmitActual(Bytecode &b);
 	Stmt*		CloneActual(Mapping *b) const;
 
@@ -52,7 +58,7 @@ public:
 	public:
 				Expander(Fragment *f) : fFragment(f) {}
 		bool	operator()(Stmt *s);
-		
+
 	private:
 		Fragment*	fFragment;
 	};
