@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "CatchStmt.h"
@@ -36,35 +40,35 @@ CatchStmt::~CatchStmt()
 
 void CatchStmt::EmitActual(Bytecode &b)
 {
-	if (b.GetTarget()->fType != kRCX_RCX2Target)
+	if ((b.GetTarget()->fType != kRCX_RCX2Target) && (b.GetTarget()->fType != kRCX_SwanTarget))
 	{
 		Error(kErr_NoTargetPartialCatch, b.GetTarget()->fName).Raise(&fLocation);
 		return;
 	}
 
 	int var = b.GetTempVar(true);
-	
+
 	if (var == kIllegalVar)
 	{
 		Error(kErr_NoMoreTemps).Raise(&fLocation);
 		return;
 	}
-	
+
 	RCX_Value ea = RCX_VALUE(kRCX_VariableType, var);
-	
+
 	b.ReleaseTempEA(ea);
-	
+
 	// move active events into temp
 	b.AddMove(var, RCX_VALUE(0x17, 0x0a));
-	
+
 	// and with mask
 	RCX_Cmd cmd;
 	cmd.MakeVar(kRCX_AndVar, var, RCX_VALUE(kRCX_ConstantType, fValue));
 	b.Add(cmd);
-	
+
 	// jump if zero
 	b.AddTest(RCX_VALUE(kRCX_ConstantType, 0), kRCX_EqualTo, RCX_VALUE(kRCX_VariableType, var), fLabel);
-	
+
 	GetBody()->Emit(b);
 }
 
