@@ -12,16 +12,23 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Compiler_h
 #define __Compiler_h
 
-#include <vector.h>
+#include <vector>
+
 #include "RCX_Constants.h"
 #include "RCX_Target.h"
 #include "RCX_Disasm.h"
 
+using std::vector;
+
 class RCX_Image;
 class Buffer;
 
@@ -36,7 +43,7 @@ public:
 
 			Compiler()	 { sCompiler = this; fDirty = false; }
 	virtual ~Compiler() {}
-	
+
 	static Compiler*	Get()	{ return sCompiler; }
 
 	void	Reset();
@@ -44,11 +51,11 @@ public:
 
 	void	Define(const char *name, const char *value=0);
 	void	Undefine(const char *name);
-	
+
 	// hooks for the lexer
 	int				AddBuffer(Buffer *b);
 	Buffer*			GetBuffer(int i)		{ return fBuffers[i]; }
-	
+
 	virtual Buffer *CreateBuffer(const char *name) = 0;
 
 	// access to system API buffer
@@ -56,13 +63,13 @@ public:
 
 	// used to insert source code into assembly listings (from RCX_SourceFiles)
 	virtual long Print(RCX_Printer *printer, short index, long start, long end);
-	
+
 private:
 	void	ReleaseBuffers();
 
 	vector<Buffer*>	fBuffers;
 	bool			fDirty;
-	
+
 	static Compiler*	sCompiler;
 };
 
