@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 2000 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "DeclareStmt.h"
@@ -24,13 +28,15 @@
 #include "Symbol.h"
 
 
-DeclareStmt::DeclareStmt(const Symbol *name, int var, const struct LexLocation &loc, int count) :
+DeclareStmt::DeclareStmt(const Symbol *name, int var, const struct LexLocation &loc, int count, bool ptr, bool stack) :
 	ChainStmt(),
 	fName(name),
 	fVar(var),
 	fScope(0),
 	fLoc(loc),
-	fCount(count)
+	fCount(count),
+        fPtr(ptr),
+        fStack(stack)
 {
 }
 
@@ -56,14 +62,14 @@ void DeclareStmt::EmitActual(Bytecode &b)
 		{
 			Error(kErr_NoMoreVars).Raise(&fLoc);
 		}
-		
+
 		fScope->RemapVar(fVar, physical, fCount);
-		
+
 		// add symbolic information
 		if (fName)
 			b.AddVariableName(physical, fName->GetKey());
 	}
-	
+
 	Stmt *body = GetBody();
 	if (body) body->Emit(b);
 }
@@ -71,10 +77,10 @@ void DeclareStmt::EmitActual(Bytecode &b)
 
 Stmt* DeclareStmt::CloneActual(Mapping *b) const
 {
-	DeclareStmt *s = new DeclareStmt(fName, fVar, fLoc, fCount);
+	DeclareStmt *s = new DeclareStmt(fName, fVar, fLoc, fCount, fPtr, fStack);
 	if (GetBody())
 		s->SetBody(GetBody()->Clone(b));
-		
+
 	return s;
 }
 
@@ -88,12 +94,12 @@ bool DeclareStmt::Binder::operator()(Stmt *s)
 		Apply(ss->GetBody(),b);
 		return false;
 	}
-	
+
 	// bind declarations to scopes
 	if (DeclareStmt *ds = dynamic_cast<DeclareStmt*>(s))
 	{
 		ds->fScope = fScope;
 	}
-	
+
 	return true;
 }
