@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "Expr.h"
@@ -38,7 +42,7 @@ Expr::~Expr()
 RCX_Value Expr::EmitAny(Bytecode &b) const
 {
 	int v;
-	
+
 	if (Evaluate(v))
 	{
 		if (v < MIN_INT || v > MAX_INT)
@@ -54,7 +58,7 @@ RCX_Value Expr::EmitAny(Bytecode &b) const
 bool Expr::EmitTo(Bytecode &b, int dst) const
 {
 	int v;
-	
+
 	if (Evaluate(v))
 	{
 		b.AddMove(dst, RCX_VALUE(kRCX_ConstantType, v));
@@ -78,15 +82,15 @@ RCX_Value Expr::EmitConstrained(Bytecode &b, long mask, bool canUseLocals) const
 	 */
 	RCX_Value ea = EmitAny(b);
 	if (ea == kIllegalEA) return ea;
-	
+
 	RCX_ValueType type = RCX_VALUE_TYPE(ea);
-	
+
 	// check ea was allowed
 	if (IsTypeInMask(mask, type) && (canUseLocals || !b.IsLocalEA(ea)))
 	{
 			return ea;
 	}
-	
+
 	// must move to another ea
 
 	// if registers are not valid, then return illegal EA
@@ -95,21 +99,21 @@ RCX_Value Expr::EmitConstrained(Bytecode &b, long mask, bool canUseLocals) const
 		Error(kErr_BadExpression).Raise(&GetLoc());
 		return kIllegalEA;
 	}
-		
+
 	// move into temp register
 	int dst = GetTempVar(b, canUseLocals);
 	if (dst == kIllegalVar) return kIllegalEA;
 
 	b.AddMove(dst, ea);
-	
+
 	// when using arrays, there's a special case when the ea is
 	// temp but not a variable.  Another case arises if the original
 	// emit was to a temp local, but they aren't allowed.
 	// call ReleaseTempEA just in case
 	b.ReleaseTempEA(ea);
-	
-	ea = RCX_VALUE(kRCX_VariableType, dst);	
-	
+
+	ea = RCX_VALUE(kRCX_VariableType, dst);
+
 	return ea;
 }
 
@@ -117,7 +121,7 @@ bool IsTypeInMask(long mask, RCX_ValueType type)
 {
 	// special case, when mask==0 all types are allowed
 	if (!mask) return true;
-	
+
 	return (1L << type) & mask;
 }
 
@@ -140,7 +144,7 @@ bool Expr::EmitSide(Bytecode &b) const
 bool Expr::EmitBranch(Bytecode &b, int label, bool condition) const
 {
 	int v;
-	
+
 	if (Evaluate(v))
 	{
 		if ((v && condition) ||
@@ -148,10 +152,10 @@ bool Expr::EmitBranch(Bytecode &b, int label, bool condition) const
 		{
 			b.AddJump(label);
 		}
-		
+
 		return true;
 	}
-	
+
 	return EmitBranch_(b, label, condition);
 }
 
@@ -159,12 +163,12 @@ bool Expr::EmitBranch(Bytecode &b, int label, bool condition) const
 RCX_Value Expr::GetStaticEA() const
 {
 	int v;
-	
+
 	if (Evaluate(v))
 	{
 		return RCX_VALUE(kRCX_ConstantType, v);
 	}
-	
+
 	return GetStaticEA_();
 }
 
@@ -178,12 +182,12 @@ RCX_Value Expr::GetStaticEA_() const
 bool Expr::EmitTo_(Bytecode &b, int dst) const
 {
 	RCX_Value ea = EmitAny_(b);
-	
+
 	if (ea == kIllegalEA) return false;
-	
+
 	b.AddMove(dst, ea);
 	b.ReleaseTempEA(ea);
-	
+
 	return true;
 }
 
@@ -192,9 +196,9 @@ bool Expr::EmitSide_(Bytecode &b) const
 {
 	vector<Expr *> v;
 	GetExprs(v);
-	for(int i=0; i<v.size(); ++i)
+	for(int i=0; i<(int)v.size(); ++i)
 		if (!v[i]->EmitSide(b)) return false;
-		
+
 	return true;
 }
 
@@ -203,7 +207,7 @@ bool Expr::EmitBranch_(Bytecode &b, int label, bool condition) const
 {
 	RCX_Value ea = EmitConstrained(b, TEST_MASK);
 	if (ea==kIllegalEA) return false;
-	
+
 	// compare ea to 0 and branch
 	b.AddTest(
 		RCX_VALUE(kRCX_ConstantType,0),
@@ -211,7 +215,7 @@ bool Expr::EmitBranch_(Bytecode &b, int label, bool condition) const
 		ea, label);
 
 	b.ReleaseTempEA(ea);
-	
+
 	return true;
 }
 
@@ -229,7 +233,7 @@ RCX_Value Expr::EmitBoolAny(Bytecode &b) const
 		b.ReleaseTempEA(dstEA);
 		return kIllegalEA;
 	}
-	
+
 	return dstEA;
 }
 
@@ -237,7 +241,7 @@ RCX_Value Expr::EmitBoolAny(Bytecode &b) const
 bool Expr::EmitBoolTo(Bytecode &b, int dst) const
 {
 	int doneLabel = b.NewLabel();
-	
+
 	if (Contains(dst))
 	{
 		/*
@@ -266,7 +270,7 @@ bool Expr::EmitBoolTo(Bytecode &b, int dst) const
 		EmitBranch(b, doneLabel, false);
 		b.AddMove(dst, RCX_VALUE(kRCX_ConstantType, 1));
 	}
-	
+
 	b.SetLabel(doneLabel);
 	return true;
 }
@@ -275,11 +279,11 @@ bool Expr::EmitBoolTo(Bytecode &b, int dst) const
 int Expr::GetTempVar(Bytecode &b, bool canUseLocals) const
 {
 	int var = b.GetTempVar(canUseLocals);
-	
+
 	if (var == kIllegalVar)
 	{
 		Error(kErr_NoMoreTemps).Raise(&GetLoc());
 	}
-	
+
 	return var;
 }
