@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Expr_h
@@ -33,7 +37,10 @@
 #include "LexLocation.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
+
 class Bytecode;
 class Mapping;
 class RCX_Target;
@@ -58,30 +65,31 @@ class RCX_Target;
  *		return false.
  *
  */
- 
+
 class Expr : public AutoFree
 {
 public:
 	enum {
 		kIllegalEA = -1
 	};
-	
+
 			Expr(const LexLocation &loc) : fLoc(loc) {}
 	virtual	~Expr() = 0;
-	
+
 	const LexLocation&	GetLoc() const { return fLoc; }
 	void				SetLoc(const LexLocation &loc)	{ fLoc = loc; }
-	
+
 	virtual Expr*		Clone(Mapping *) const = 0;
-	
+
 	virtual bool		Evaluate(int & /*value */) const	{ return false; }
-	
+
 	virtual bool		PotentialLValue() const	{ return false; }
 	virtual int			GetLValue() const	{ return kIllegalVar; }
 			RCX_Value	GetStaticEA() const;
-			
+
 	virtual bool		PromiseConstant() const { return true; }
 	virtual bool		Contains(int /* var */) const { return false; }
+        virtual bool            LValueIsPointer() const { return false; }
 
 	// append sub-expressions into vector
 	virtual void		GetExprs(vector<Expr*> & /* v */) const { }
@@ -93,22 +101,22 @@ public:
 	bool		EmitSide(Bytecode &b) const;
 	bool		EmitBranch(Bytecode &b, int label, bool condition) const;
 	RCX_Value	EmitMath(Bytecode &b) const;
-	
+
 protected:
 	// virtual code emit methods for derrived classes
 	virtual RCX_Value	EmitAny_(Bytecode &b) const = 0;
 	virtual bool		EmitTo_(Bytecode &b, int dst) const;
 	virtual bool		EmitSide_(Bytecode &) const;
 	virtual bool		EmitBranch_(Bytecode &b, int label, bool condition) const;
-	
+
 	virtual RCX_Value	GetStaticEA_() const;
-	
-	
+
+
 	// helper routines for EmitAny_() and EmitTo_() implementations
 	RCX_Value	EmitBoolAny(Bytecode &b) const;
 	bool		EmitBoolTo(Bytecode &b, int dst) const;
-	
-	
+
+
 	// utility function
 	int GetTempVar(Bytecode &b, bool canUseLocals=true) const;
 
