@@ -12,9 +12,13 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
-#include <string.h>
+#include <cstring>
 #include "ExprStmt.h"
 #include "Bytecode.h"
 #include "Expr.h"
