@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Fragment_h
@@ -37,6 +41,10 @@
 #include "LocationNode.h"
 #endif
 
+#ifndef __FunctionDef_h
+#include "FunctionDef.h"
+#endif
+
 class Symbol;
 class Stmt;
 class Bytecode;
@@ -53,34 +61,52 @@ public:
 		kMultiTaskID = -2
 	};
 
-				Fragment(bool isTask, Symbol *name, Stmt *body);
-				~Fragment();
+        Fragment(bool isTask, Symbol *name, Stmt *body);
+        Fragment(bool isTask);
+	~Fragment();
+
+        bool		AddArg(const Symbol *name, FunctionDef::ArgType type);
+        int		GetArgCount() const	{ return fArgs.size(); }
+        const Symbol*	GetArgName(int i) const	{ return fArgs[i].fName; }
+        FunctionDef::ArgType		GetArgType(int i) const	{ return fArgs[i].fType; }
+        int		GetArgVar(int i) const	{ return fArgs[i].fVar; }
 
 	void		SetLocations(LocationNode *start, LocationNode *end);
 
-	int					GetNumber()	const	{ return fNumber; }
-	Symbol*				GetName() const		{ return fName; }
-	bool				IsTask() const		{ return fIsTask; }
-	RCX_ChunkType		GetChunkType() const	{ return fIsTask ? kRCX_TaskChunk : kRCX_SubChunk; }
-	int					GetTaskID() const	{ return fTaskID; }
-	Stmt*				GetBody()			{ return fBody; }
-	int					GetLocalMask() const	{ return fLocalMask; }
-	void				SetLocalMask(int m)	{ fLocalMask = m; }
-	
+        void		CreateArgVars();
+
+	int		GetNumber()	const	{ return fNumber; }
+        void		SetName(Symbol *name);
+	Symbol*		GetName() const		{ return fName; }
+	bool		IsTask() const		{ return fIsTask; }
+	RCX_ChunkType	GetChunkType() const	{ return fIsTask ? kRCX_TaskChunk : kRCX_SubChunk; }
+	int		GetTaskID() const	{ return fTaskID; }
+        void		SetBody(Stmt *stmt);
+	Stmt*		GetBody()		{ return fBody; }
+	int		GetLocalMask() const	{ return fLocalMask; }
+	void		SetLocalMask(int m)	{ fLocalMask = m; }
+
 	void		SetNumber(int n)	{ fNumber = n; }
 	void		AssignTaskID(int n);	// only affects kRCX_SubFragment types
-	void		SetBody(Stmt *s)	{ fBody = s; }
-	
+
 	void		Emit(Bytecode &b);
 	void		Check();
-	
+
 private:
+        struct Arg
+        {
+                const Symbol *	        fName;
+                FunctionDef::ArgType    fType;
+                int                     fVar;
+        };
+
+        vector<Arg>	fArgs;
 	bool		fIsTask;
 	Symbol*		fName;
 	Stmt*		fBody;
-	int			fNumber;
-	int			fTaskID;
-	int			fLocalMask;
+	int		fNumber;
+	int		fTaskID;
+	int		fLocalMask;
 	LexLocation	fStart;
 	LexLocation	fEnd;
 };
