@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -38,15 +42,15 @@ FunctionDef::~FunctionDef()
 bool FunctionDef::AddArg(const Symbol *name, ArgType type)
 {
 	Arg a;
-	
+
 	for(size_t i=0; i<fArgs.size(); i++)
 	{
 		if (fArgs[i].fName == name) return false;
 	}
-	
+
 	a.fName = name;
 	a.fType = type;
-	
+
 	fArgs.push_back(a);
 	return true;
 }
@@ -66,9 +70,9 @@ void FunctionDef::CreateArgVars()
 	for(size_t i=0; i<fArgs.size(); i++)
 	{
 		int var;
-		
+
 		var = gProgram->NextVirtualVar();
-		
+
 		switch(fArgs[i].fType)
 		{
 			case kConstantArg:
@@ -78,12 +82,20 @@ void FunctionDef::CreateArgVars()
 			case kSensorArg:
 				var |= kVirtualReadOnlyFlag;
 				break;
+                        case kPointerArg:
+                                var |= kPointerFlag;
+                                break;
+                        case kConstPtrArg:
+                                var |= kVirtualReadOnlyFlag | kPointerFlag;
+                                break;
 			default:
 				break;
 		}
 
 		fArgs[i].fVar = var;
-		gProgram->DefineVar(fArgs[i].fName, var, false);
+		gProgram->DefineVar(fArgs[i].fName, var, false,
+                  ((fArgs[i].fType == kPointerArg) || (fArgs[i].fType == kConstPtrArg)),
+                  false);
 	}
 }
 
@@ -92,7 +104,7 @@ void FunctionDef::SetLocations(LocationNode *start, LocationNode *end)
 {
 	fStart = start->GetLoc();
 	delete start;
-	
+
 	fEnd = end->GetLoc();
 	delete end;
 }
