@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -31,7 +35,9 @@
 #include "LocationNode.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Symbol;
 class Stmt;
@@ -47,54 +53,56 @@ public:
 		kIntegerArg,
 		kReferenceArg,
 		kConstRefArg,
-		kSensorArg
+                kSensorArg,
+                kPointerArg,
+                kConstPtrArg
 	};
-	
-					FunctionDef();
-					~FunctionDef();
 
-	bool			AddArg(const Symbol *name, ArgType type);
-	int				GetArgCount() const	{ return fArgs.size(); }
+			FunctionDef();
+			~FunctionDef();
+
+	bool		AddArg(const Symbol *name, ArgType type);
+	int		GetArgCount() const	{ return fArgs.size(); }
 	const Symbol*	GetArgName(int i) const	{ return fArgs[i].fName; }
-	ArgType			GetArgType(int i) const	{ return fArgs[i].fType; }
-	int				GetArgVar(int i) const	{ return fArgs[i].fVar; }
+	ArgType		GetArgType(int i) const	{ return fArgs[i].fType; }
+	int		GetArgVar(int i) const	{ return fArgs[i].fVar; }
+
+	void		SetBody(Stmt *stmt);
+	Stmt*		GetBody()	{ return fBody; }
+
+	void		SetName(const Symbol *name)	{ fName = name; }
+	const Symbol*	GetName() const			{ return fName; }
 
-	void			SetBody(Stmt *stmt);
-	Stmt*			GetBody()	{ return fBody; }
-	
-	void			SetName(const Symbol *name)	{ fName = name; }
-	const Symbol*	GetName() const				{ return fName; }
-	
 	// support for source code listings
-	void			SetListingEnabled(bool b)	{ fListingEnabled = b; }
-	bool			GetListingEnabled() const	{ return fListingEnabled; }
-	void			SetLocations(LocationNode *start, LocationNode *end);
+	void		SetListingEnabled(bool b)	{ fListingEnabled = b; }
+	bool		GetListingEnabled() const	{ return fListingEnabled; }
+	void		SetLocations(LocationNode *start, LocationNode *end);
 	const LexLocation& GetStartLoc() const	{ return fStart; }
 	const LexLocation& GetEndLoc() const	{ return fEnd; }
-	
-	void			CreateArgVars();
-	
-	bool			IsExpanded() const	{ return fExpanded; }
-	void			SetExpanded(bool b)	{ fExpanded = b; }
-	
+
+	void		CreateArgVars();
+
+	bool		IsExpanded() const	{ return fExpanded; }
+	void		SetExpanded(bool b)	{ fExpanded = b; }
+
 private:
-	const Symbol*		fName;
-	
+	const Symbol*	fName;
+
 	struct Arg
 	{
 		const Symbol *	fName;
-		ArgType			fType;
-		int				fVar;
+		ArgType		fType;
+		int		fVar;
 	};
-	
-	vector<Arg>			fArgs;
-	Stmt*				fBody;
 
-	bool				fExpanded;
-	
-	bool				fListingEnabled;
-	LexLocation			fStart;
-	LexLocation			fEnd;
+	vector<Arg>		fArgs;
+	Stmt*			fBody;
+
+	bool			fExpanded;
+
+	bool			fListingEnabled;
+	LexLocation		fStart;
+	LexLocation		fEnd;
 };
 
 #endif
