@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -22,7 +26,9 @@
 #include "Variable.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Expr;
 
@@ -34,18 +40,18 @@ public:
 
 	void		Add(int var, Expr *value);
 	const Expr*	Get(int var) const;
-	
+
 	int			GetMappedVar(int var) const;
 
 private:
 	struct Pair
 	{
 				Pair(int v, Expr *e) : fVar(v), fValue(e) {}
-				
+
 		int		fVar;
 		Expr*	fValue;
 	};
-	
+
 	vector<Pair>	fPairs;
 };
 
