@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "MonitorStmt.h"
@@ -63,7 +67,7 @@ void MonitorStmt::EmitActual(Bytecode &b)
 	RCX_Cmd cmd;
 	int handlerLabel = b.NewLabel();
 	int endLabel = b.NewLabel();
-	
+
 	// get EA of event mask
 	if (b.GetTarget()->fType == kRCX_ScoutTarget)
 		ea = fEvents->EmitConstrained(b, SCOUT_MONITOR_MASK);
@@ -71,19 +75,19 @@ void MonitorStmt::EmitActual(Bytecode &b)
 		ea = fEvents->EmitAny(b);
 
 	if (ea==Expr::kIllegalEA) return;
-	
-	// start event monitoring	
-	cmd.Set(0xb5, RCX_VALUE_TYPE(ea), RCX_VALUE_DATA(ea), RCX_VALUE_DATA(ea) >> 8, 0, 0);
+
+	// start event monitoring
+	cmd.Set(kRCX_StartEventMonOp, RCX_VALUE_TYPE(ea), RCX_VALUE_DATA(ea), RCX_VALUE_DATA(ea) >> 8, 0, 0);
 	b.Add(cmd);
-	b.AddFixup(Bytecode::kSignBitLongFixup, handlerLabel, 4, 0xb4);
+	b.AddFixup(Bytecode::kSignBitLongFixup, handlerLabel, 4, kRCX_SStartEventMonOp);
 	b.ReleaseTempEA(ea);
-	
+
 	GetPrimary()->Emit(b);
-	
+
 	// end event monitoring
-	cmd.Set(0xb0);
+	cmd.Set(kRCX_ExitEventCheckOp);
 	b.Add(cmd);
-	
+
 	// now iterate through handlers (which must be a block stmt
 	BlockStmt *handlers = dynamic_cast<BlockStmt*>(GetSecondary());
 	if (handlers)
@@ -92,10 +96,11 @@ void MonitorStmt::EmitActual(Bytecode &b)
 		{
 			b.AddJump(endLabel);
 			b.SetLabel(handlerLabel);
-			
+
 			// prepare next handler test
-			handlerLabel = b.NewLabel();
-			
+//                        handlerLabel = b.NewLabel();
+                        b.NewLabel();
+
 			CatchStmt* cs = dynamic_cast<CatchStmt*>(h);
 			if (cs)
 			{
@@ -105,7 +110,7 @@ void MonitorStmt::EmitActual(Bytecode &b)
 			}
 			else
 				handlerLabel = kIllegalLabel;
-			
+
 			h->Emit(b);
 		}
 	}
@@ -113,7 +118,7 @@ void MonitorStmt::EmitActual(Bytecode &b)
 		b.SetLabel(handlerLabel);
 
 	b.SetLabel(endLabel);
-		
+
 	b.EndHandler(Bytecode::kEventHandler);
 }
 
