@@ -12,8 +12,12 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
- 
+
 /*
  * PreProc reads tokens from the Lexer and emits a preprocessed token stream.
  * The entire process is 'pulled' by calling PreProc::Get(), which in turn calls
@@ -32,7 +36,7 @@
  *
  */
 
-#include <string.h>
+#include <cstring>
 #include "PreProc.h"
 #include "Symbol.h"
 #include "Macro.h"
@@ -66,17 +70,17 @@ int PreProc::Get(TokenVal &v)
 {
 	int t;
 	long x;
-	
+
 	// read token from lexer, and process any preprocessor commands;
 	while(1)
 	{
 		t = GetReplacedToken(v);
-		
+
 		// strip newlines
 		if (t==NL) continue;
-		
+
 		fNLRead = false;
-		
+
 		// check for end
 		if (t==0)
 		{
@@ -84,7 +88,7 @@ int PreProc::Get(TokenVal &v)
 				Error(kErr_UnterminatedIfdef).RaiseLex();
 			return 0;
 		}
-		
+
 		// preprocessor commands
 		switch(t)
 		{
@@ -108,7 +112,7 @@ int PreProc::Get(TokenVal &v)
 				fActive = fConditional.IsActive();
 				DiscardLine();
 				break;
-				
+
 			case PP_ELIF:
 				fActive=true;
 				fParser.Parse(x);
@@ -118,7 +122,7 @@ int PreProc::Get(TokenVal &v)
 					fActive = fConditional.IsActive();
 				DiscardLine();
 				break;
-			
+
 			case PP_ELSE:
 				if (!fConditional.Else())
 					Error(kErr_UnexpectedElse, "#else").RaiseLex();
@@ -152,7 +156,7 @@ int PreProc::Get(TokenVal &v)
 			case PP_WARNING:
 				Error(kWarn_WarningDirective).RaiseLex();
 				DiscardLine();
-				break;			
+				break;
 			case PP_UNKNOWN:
 				if (fActive)
 					Error(kErr_UnknownDirective).RaiseLex();
@@ -169,11 +173,11 @@ int PreProc::Get(TokenVal &v)
 int PreProc::GetReplacedToken(TokenVal &v)
 {
 	int t;
-	
+
 	while(1)
 	{
 		t = GetRawToken(v);
-		
+
 		// macro substitution
 		if (t==ID && (v.fSymbol->IsDefined()) && fActive)
 		{
@@ -218,16 +222,16 @@ int PreProc::GetRawToken(TokenVal &v)
 			{
 				return 0;
 			}
-			
+
 			t = yylex(v);
 
 			if (t==NL)
 				fNLRead = true;
 			else if (t==0)
 				fEndOfFiles = true;
-				
+
 			return t;
-		}	
+		}
 	}
 }
 
@@ -235,22 +239,22 @@ int PreProc::GetRawToken(TokenVal &v)
 bool PreProc::DoInclude()
 {
 	TokenVal v;
-	
+
 	int t = GetRawToken(v);
 	DiscardLine();
-	
+
 	if (t != STRING)
 	{
 		Error(kErr_IncludeNeedsName).RaiseLex();
 		return false;
 	}
-	
+
 	if (!LexFindAndPushFile(v.fString))
 	{
 		Error(kErr_FileOpen, v.fString);
 		return false;
 	}
-	
+
 	return true;
 }
 
@@ -261,33 +265,33 @@ bool PreProc::DoDefine()
 	TokenVal v;
 	int t;
 	int argCount;
-	
+
 	t = GetRawToken(v);
 	if (t != ID)
 	{
 		Error(kErr_SymbolNameNeeded, "#define").RaiseLex();
 		return false;
 	}
-	
+
 	s = v.fSymbol;
 	if (s->IsDefined())
 	{
 		Error(kErr_DefineRedef, s->GetKey()).RaiseLex();
 		return false;
 	}
-	
+
 	argCount = ReadDefineArgs();
 	if (argCount == kErrorArgs) return false;
-	
+
 	// hack to detect empty macro
 	if (fNLRead)
 	{
 		s->Define(new Macro(0, nil, -1));
 		return true;
 	}
-	
+
 	ReadDefineBody();
-	
+
 	s->Define(new Macro(&fTokenBuf[0], fTokenBuf.size(), argCount));
 	return true;
 }
@@ -300,7 +304,7 @@ void PreProc::ReadDefineBody()
 	int count = 0;
 	fTokenBuf.resize(0);
 	int argnum;
-	
+
 	while(1)
 	{
 		t = GetRawToken(v);
@@ -320,7 +324,7 @@ void PreProc::ReadDefineBody()
 				break;
 
 		}
-		
+
 		fTokenBuf.resize(count+1);
 		fTokenBuf[count].fType = t;
 		fTokenBuf[count].fValue = v;
@@ -332,10 +336,10 @@ void PreProc::ReadDefineBody()
 int PreProc::MatchArg(const Symbol *s)
 {
 	size_t i;
-	
+
 	for(i=0; i<fArguments.size(); i++)
 		if (fArguments[i] == s) return i;
-	
+
 	return -1;
 }
 
@@ -344,20 +348,20 @@ int PreProc::ReadDefineArgs()
 {
 	int t;
 	TokenVal v;
-	
+
 	fArguments.resize(0);
 
 	// check for space or '('
 	LexReturnWhitespace(1);
 	t = GetRawToken(v);
 	LexReturnWhitespace(0);
-	
+
 	switch(t)
 	{
 		case WS:
 		case NL:
 			return Macro::kNoArgs;
-		case '(':
+                case '(':
 			break;
 		default:
 			Error(kErr_DefineArgs).RaiseLex();
@@ -367,18 +371,18 @@ int PreProc::ReadDefineArgs()
 	while(1)
 	{
 		t = GetRawToken(v);
-		
+
 		// check for empty arg list
-		if (t==')' && fArguments.size() ==0) return 0;
-		
+		if (t==')' && fArguments.size()==0) return 0;
+
 		if (t != ID)
 		{
 			if (t != NL) DiscardLine();
 			return kErrorArgs;
 		}
-		
+
 		fArguments.push_back(v.fSymbol);
-		
+
 		t = GetRawToken(v);
 		if (t == ')')
 			return fArguments.size();
@@ -395,22 +399,22 @@ bool PreProc::BeginExpansion(Symbol *s)
 {
 	Expansion *e;
 	Macro *def = s->GetDefinition();
-	
+
 	if (def->IsMarked())
 	{
 		Error(kErr_CircularDef, s->GetKey()).RaiseLex();
 		return false;
 	}
-	
+
 	e = new Expansion(def);
-	
+
 	if (!ReadExpansionArgs(e))
 	{
 		delete e;
 		Error(kErr_WrongArgCount, s->GetKey()).RaiseLex();
 		return false;
 	}
-	
+
 	fExpList.InsertHead(e);
 	return true;
 }
@@ -421,15 +425,15 @@ bool PreProc::ReadExpansionArgs(Expansion *e)
 	int argCount = e->GetArgCount();
 	int t;
 	TokenVal v;
-	
+
 	if (argCount == Macro::kNoArgs) return true;
-	
+
 	t = GetRawToken(v);
 	if (t != '(') return false;
 
 	for(int i=0; i<argCount-1; i++)
 		if (!ReadExpansionArg(e, i, ',')) return false;
-	
+
 	if (argCount == 0)
 	{
 		t = GetRawToken(v);
@@ -437,7 +441,7 @@ bool PreProc::ReadExpansionArgs(Expansion *e)
 	}
 	else
 		if (!ReadExpansionArg(e, argCount-1, ')')) return false;
-		
+
 	return true;
 }
 
@@ -450,7 +454,7 @@ bool PreProc::ReadExpansionArg(Expansion *e, int i, int delim)
 	TokenVal v;
 
 	fTokenBuf.resize(0);
-	
+
 	while(1)
 	{
 		t = GetRawToken(v);
@@ -475,13 +479,13 @@ bool PreProc::ReadExpansionArg(Expansion *e, int i, int delim)
 				e->SetArg(i, &fTokenBuf[0], fTokenBuf.size());
 				return true;
 		}
-				
+
 		fTokenBuf.resize(count+1);
 		fTokenBuf[count].fType = t;
 		fTokenBuf[count].fValue = v;
 		count++;
 	}
-	
+
 }
 
 
@@ -490,7 +494,7 @@ bool PreProc::DoIfdef(bool b)
 	TokenVal v;
 	int t;
 	bool defined;
-	
+
 	t = GetRawToken(v);
 	if (t != ID)
 	{
@@ -509,14 +513,14 @@ bool PreProc::DoUndef()
 {
 	TokenVal v;
 	int t;
-	
+
 	t = GetRawToken(v);
 	if (t != ID)
 	{
 		Error(kErr_SymbolNameNeeded, "#undef").RaiseLex();
 		return false;
 	}
-	
+
 	v.fSymbol->Undefine();
 	return true;
 }
@@ -528,9 +532,9 @@ bool PreProc::DoPragma()
 
 	int t = GetRawToken(v);
 	if (t != ID) return false;
-	
+
 	const char *pragma = v.fSymbol->GetKey();
-	
+
 	if (strcmp(pragma, "noinit") == 0)
 	{
 		gProgram->SetInitName(0, 0);
@@ -548,11 +552,11 @@ bool PreProc::DoPragma()
 	else if (strcmp(pragma, "reserve") == 0)
 	{
 		int start, end;
-		
+
 		t = GetRawToken(v);
 		if (t != NUMBER) return false;
 		start = v.fInt;
-		
+
 		t = GetRawToken(v);
 		if (t == NUMBER)
 			end = v.fInt;
@@ -560,13 +564,13 @@ bool PreProc::DoPragma()
 			end = start;
 		else
 			return false;
-		
+
 		if (!gProgram->ReserveVars(start, end))
 			Error(kErr_CouldNotReserveVars).RaiseLex();
-		
+
 		return true;
 	}
-	
+
 	return false;
 }
 
@@ -575,9 +579,9 @@ void PreProc::DiscardLine()
 {
 	TokenVal v;
 	int t;
-	
+
 	if (fNLRead) return;
-	
+
 	while((t=GetRawToken(v)) != 0)
 	{
 		if (t==NL) return;
