@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "Program.h"
@@ -38,14 +42,14 @@ Program::Program(const RCX_Target *target) :
 	fVarAllocator(target->fMaxGlobalVars, target->fMaxTaskVars)
 {
 	fTarget = target;
-	
-	// set fFragNumbers array to the first available number for each type 
+
+	// set fFragNumbers array to the first available number for each type
 	for(int i=0; i<kRCX_ChunkTypeCount; ++i)
 	{
 		fChunkNumbers[i] = target->fRanges[i].fBase;
 	}
 	fChunkNumbers[kRCX_TaskChunk]++; // leave room for main
-	
+
 	fMainAdded = false;
 	fScopes.InsertHead(new Scope());
 	fInitName = Symbol::Get("_init");
@@ -62,13 +66,13 @@ Program::~Program()
 
 	while(Fragment *f=fSubs.RemoveHead())
 		delete f;
-	
+
 	while(Scope *s=fScopes.RemoveHead())
 		delete s;
 
 	while(FunctionDef *func = fFunctions.RemoveHead())
 		delete func;
-		
+
 	delete fGlobalDecls;
 }
 
@@ -76,7 +80,7 @@ Program::~Program()
 int Program::AddFragment(Fragment *f)
 {
 	CheckName(f->GetName());
-	
+
 	if (f->IsTask()) {
 		if (f->GetName() == Symbol::Get("main"))
 		{
@@ -114,7 +118,7 @@ void Program::AddGlobalDecls(BlockStmt *b)
 	// all of the children of b to the fGlobalDecls
 	// block.  Later on (in AllocateGlobals() we'll check
 	// to make sure they are really DeclareStmts
-	
+
 	while(Stmt *s = b->RemoveHead())
 	{
 		fGlobalDecls->Add(s);
@@ -127,21 +131,21 @@ void Program::AddGlobalDecls(BlockStmt *b)
 void Program::AddResource(Resource *r)
 {
 	CheckName(r->GetName());
-	
+
 	RCX_ChunkType type = r->GetType();
-	
+
 	if (type < kRCX_SoundChunk || type >= kRCX_ChunkTypeCount)
 	{
 		Error(kErr_BadResourceType).RaiseLex();
 		return;
 	}
-	
+
 	if (fChunkNumbers[type] >= fTarget->GetChunkLimit(type))
 	{
 		Error(kErr_TooManyResources, fTarget->fRanges[type].fCount).RaiseLex();
 		return;
 	}
-	
+
 	r->SetNumber(fChunkNumbers[type]++);
 	fResources.InsertTail(r);
 }
@@ -154,18 +158,18 @@ void Program::CheckName(const Symbol *name)
 }
 
 
-int Program::CreateVar(const Symbol *name, bool array)
+int Program::CreateVar(const Symbol *name, bool array, bool ptr, bool stack)
 {
 	int var;
-	
+
 	var = NextVirtualVar();
 	if (fScopes.GetHead()->GetNext()==0)
 	{
 		// global var
 		// probably should remember the name somewhere
 	}
-	
-	DefineVar(name, var, array);
+
+	DefineVar(name, var, array, ptr, stack);
 	return var;
 }
 
@@ -176,7 +180,7 @@ int Program::NextVirtualVar()
 }
 
 
-void Program::DefineVar(const Symbol *name, int var, bool array)
+void Program::DefineVar(const Symbol *name, int var, bool array, bool ptr, bool stack)
 {
 	Scope *s = fScopes.GetHead();
 
@@ -185,16 +189,16 @@ void Program::DefineVar(const Symbol *name, int var, bool array)
 		Error(kErr_SymRedef, name->GetKey()).RaiseLex();
 	}
 	else
-		s->Define(name, var, array);
+		s->Define(name, var, array, ptr, stack);
 }
 
 
-int Program::GetVar(const Symbol *name, bool &array)
+int Program::GetVar(const Symbol *name, bool &array, bool &ptr, bool &stack)
 {
-	int var = fScopes.GetHead()->Lookup(name, array);
+	int var = fScopes.GetHead()->Lookup(name, array, ptr, stack);
 	if (var == kIllegalVar)
 		Error(kErr_Undeclared, name->GetKey());
-	
+
 	return var;
 }
 
@@ -211,20 +215,20 @@ void Program::SetInitName(Symbol *name, LexLocation *location)
 		fInitLocation.fIndex = kIllegalSrcIndex;
 	}
 }
-	
+
 #include "RCX_SpyboticsLinker.h"
-	
+
 RCX_Image*	Program::CreateImage()
 {
 	RCX_Image *image;
-	
+
 	image = new RCX_Image();
 	image->SetTargetType(fTarget->fType);
 
 	if (!AllocateGlobals(image)) return image;
 	if (!PrepareMainTask()) return image;
 	if (!CheckFragments()) return image;
-			
+
 	// emit subs
 	for(Fragment *sub=fSubs.GetHead(); sub; sub=sub->GetNext())
 		EncodeFragment(image, sub);
@@ -232,7 +236,7 @@ RCX_Image*	Program::CreateImage()
 	// emit tasks
 	for(Fragment *task=fTasks.GetHead(); task; task=task->GetNext())
 		EncodeFragment(image, task);
-	
+
 	// copy resources
 	for(Resource *r=fResources.GetHead(); r; r=r->GetNext())
 	{
@@ -240,7 +244,7 @@ RCX_Image*	Program::CreateImage()
 			r->GetData(), r->GetLength(), r->GetName()->GetKey(),
 			0, 0);
 	}
-	
+
 	return image;
 }
 
@@ -259,14 +263,14 @@ void Program::EncodeFragment(RCX_Image *image, Fragment *f)
 		mode = VarAllocator::kSingleSubMode;
 
 	fVarAllocator.Begin(mode);
-		
+
 	f->Emit(*b);
 	image->AddChunk(f->GetChunkType(), f->GetNumber(),
 		b->GetData(), b->GetLength(), f->GetName()->GetKey(),
 		b->GetSourceTags(), b->GetSourceTagCount());
 
 	f->SetLocalMask(fVarAllocator.End());
-	
+
 	delete b;
 }
 
@@ -283,10 +287,10 @@ bool Program::PrepareMainTask()
 	// insert block into main task so we have a place for init code
 	Fragment *mainTask = fTasks.GetHead();
 	BlockStmt *mainBlock = new BlockStmt();
-	
+
 	mainBlock->Add(mainTask->GetBody());
 	mainTask->SetBody(mainBlock);
-	
+
 	// insert call for init routine into main task
 	if (fInitName)
 	{
@@ -304,7 +308,7 @@ bool Program::PrepareMainTask()
 			return false;
 		}
 	}
-	
+
 	// insert init stmts into main task
 	mainBlock->Prepend(fGlobalDecls);
 	fGlobalDecls = 0;
@@ -328,18 +332,18 @@ bool Program::CheckFragments()
 		Error(kErr_TooManySubs, fTarget->fRanges[kRCX_SubChunk].fCount).Raise(0);
 		ok = false;
 	}
-			
+
 	Fragment *f;
 	for(f=fTasks.GetHead(); f; f=f->GetNext())
 	{
 		f->Check();
 	}
-	
+
 	for(f=fSubs.GetHead(); f; f=f->GetNext())
 	{
 		f->Check();
 	}
-		
+
 	return ok;
 }
 
@@ -350,7 +354,7 @@ bool Program::Defined(const Symbol *name) const
 	if (Find(fSubs, name)) return true;
 	if (Find(fFunctions, name)) return true;
 	if (Find(fResources, name)) return true;
-	
+
 	return fScopes.GetTail()->Contains(name);
 }
 
@@ -370,14 +374,14 @@ void Program::PopScope()
 
 
 bool Program::AllocateGlobals(RCX_Image *image)
-{	
+{
 	for(Stmt *s=fGlobalDecls->GetHead(); s; s=s->GetNext())
 	{
 		DeclareStmt *dec = dynamic_cast<DeclareStmt*>(s);
 		PASSERT(dec);
-		
+
 		int from = dec->GetVar();
-		
+
 		// global scope
 		int to = fVarAllocator.Allocate(false, false, dec->GetCount());
 		if (to == kIllegalVar)
@@ -389,7 +393,7 @@ bool Program::AllocateGlobals(RCX_Image *image)
 		image->SetVariable(to, dec->GetName()->GetKey());
 		TranslateVar(from, to);
 	}
-	
+
 	return true;
 }
 
@@ -397,7 +401,7 @@ bool Program::AllocateGlobals(RCX_Image *image)
 void Program::TranslateVar(int from, int to)
 {
 	VarTranslator vt(from, to);
-	
+
 	for(Fragment *f=fTasks.GetHead(); f; f=f->GetNext())
 		Apply(f->GetBody(), vt);
 
@@ -415,9 +419,9 @@ void Program::TranslateVar(int from, int to)
 bool Program::ReserveVars(int start, int end)
 {
 	if (end < start) return false;
-	
+
 	for(int v=start; v<=end; ++v)
 		if (!fVarAllocator.Reserve(v)) return false;
-		
+
 	return true;
 }
