@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Program_h
@@ -59,7 +63,9 @@
 
 
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Fragment;
 class Resource;
@@ -95,42 +101,42 @@ template <class T> const T*Find(const PListS<T> &list, const Symbol *name)
 class Program
 {
 public:
-			Program(const RCX_Target *target);
-			~Program();
-	
+	Program(const RCX_Target *target);
+	~Program();
+
 
 	const RCX_Target*	GetTarget() const	{ return fTarget; }
-	
+
 	// adding tasks and other stuff...
-	int		AddFragment(Fragment *f);
-	void	AddResource(Resource *r);	
+	int	AddFragment(Fragment *f);
+	void	AddResource(Resource *r);
 	void	AddFunction(FunctionDef *f);
 	void	AddGlobalDecls(BlockStmt *s);
-	
+
 	RCX_Image	*CreateImage();
-	
-	// variable allocation, etc.	
-	int			CreateVar(const Symbol *name, bool array);
-	int			GetVar(const Symbol *name, bool &array);
-	int			NextVirtualVar();
-	void		DefineVar(const Symbol *name, int var, bool array);
-	
+
+	// variable allocation, etc.
+	int	CreateVar(const Symbol *name, bool array, bool ptr, bool stack);
+	int	GetVar(const Symbol *name, bool &array, bool &ptr, bool &stack);
+	int	NextVirtualVar();
+	void	DefineVar(const Symbol *name, int var, bool array, bool ptr, bool stack);
+
 	// getting tasks, etc
 	Fragment*	GetTask(const Symbol *name) { return Find(fTasks, name); }
 	Fragment*	GetSub(const Symbol *name) { return Find(fSubs, name); }
 	FunctionDef*	GetFunction(const Symbol *name) { return Find(fFunctions, name); }
 	const Resource*	GetResource(const Symbol *name) const { return Find(fResources, name); }
-	
+
 	// check all symbols (tasks, variables, etc)
 	bool		Defined(const Symbol *name) const;
-	
+
 	Scope*		PushScope();
-	void		PopScope();	
-		
+	void		PopScope();
+
 	void		SetInitName(Symbol *name, LexLocation *location);
-	
+
 	bool		ReserveVars(int start, int end);
-	
+
 private:
 	void		EncodeFragment(RCX_Image *image, Fragment *f);
 	void		CheckName(const Symbol *name);
@@ -142,23 +148,23 @@ private:
 	void		TranslateVar(int from, int to);
 
 	// fields
-	VarAllocator	fVarAllocator;
+	VarAllocator	        fVarAllocator;
 	PListS<Fragment>	fTasks;
 	PListS<Fragment>	fSubs;
 	PListS<FunctionDef>	fFunctions;
 	PListS<Resource>	fResources;
-	
-	bool			fMainAdded;	
-	int				fChunkNumbers[kRCX_ChunkTypeCount];
-	
+
+	bool		fMainAdded;
+	int		fChunkNumbers[kRCX_ChunkTypeCount];
+
 	PListS<Scope>	fScopes;
-	Symbol*			fInitName;
-	LexLocation		fInitLocation;
-	
+	Symbol*		fInitName;
+	LexLocation	fInitLocation;
+
 	BlockStmt*		fGlobalDecls;
 	const RCX_Target*	fTarget;
-		
-	int				fVirtualVarCount;
+
+	int		fVirtualVarCount;
 };
 
 
