@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __RepeatStmt_h
@@ -28,10 +32,9 @@ class RepeatStmt : public ChainStmt
 public:
 			RepeatStmt(Expr *c, Stmt *s);
 			~RepeatStmt();
-	
-	void	ComputeNullable();
+
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 
 	virtual void	GetExprs(vector<Expr*> & v) const;
 
@@ -40,9 +43,9 @@ private:
 	void	EmitRCXVar(Bytecode &b);
 	void	EmitDecJump(Bytecode &b);
 	int		EmitCountToTemp(Bytecode &b);
-	
+
 	Expr*	fCount;
-	
+
 	// flag to indicate if rcx loop counter can be used
 	static bool sRCXLoopInUse;
 };
