@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -27,40 +31,42 @@ Scope::~Scope()
 }
 
 
-bool Scope::Define(const Symbol *name, int var, bool array)
+bool Scope::Define(const Symbol *name, int var, bool array, bool ptr, bool stack)
 {
 	if (Contains(name))
 		return false;
 
-	fBindings.push_back(Mapping(name, var, array));
+	fBindings.push_back(ScopeData(name, var, array, ptr, stack));
 	return true;
 }
 
 
-int Scope::Lookup(const Symbol *name, bool &array)
+int Scope::Lookup(const Symbol *name, bool &array, bool &ptr, bool &stack)
 {
 	Scope *s;
-	
+
 	for(s=this; s; s=s->GetNext())
 	{
-		int var = s->Lookup1(name, &array);
+		int var = s->Lookup1(name, &array, &ptr, &stack);
 		if (var != kIllegalVar) return var;
 	}
-	
+
 	return kIllegalVar;
 }
 
 
-int	Scope::Lookup1(const Symbol *name, bool *array)
+int	Scope::Lookup1(const Symbol *name, bool *array, bool *ptr, bool *stack)
 {
 	for(size_t i=0; i<fBindings.size(); i++)
 	{
 		if (fBindings[i].fName == name)
 		{
 			if (array) *array = fBindings[i].fArray;
+                        if (ptr) *ptr = fBindings[i].fPtr;
+                        if (stack) *stack = fBindings[i].fStack;
 			return fBindings[i].fVar;
 		}
 	}
-	
+
 	return kIllegalVar;
 }
