@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -30,7 +34,9 @@
 #include "AutoFree.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Symbol;
 
@@ -38,27 +44,30 @@ class Symbol;
 class Scope : public PLinkS<Scope>, public AutoFree
 {
 public:
-				Scope();
-				~Scope();
+	Scope();
+	~Scope();
+
+	bool	Define(const Symbol *name, int var, bool array, bool ptr, bool stack);
+	int	Lookup(const Symbol *name, bool &array, bool &ptr, bool &stack);
+	bool	Contains(const Symbol *name)	{ return Lookup1(name)!= kIllegalVar; }
 
-	bool				Define(const Symbol *name, int var, bool array);
-	int					Lookup(const Symbol *name, bool &array);
-	bool				Contains(const Symbol *name)	{ return Lookup1(name)!= kIllegalVar; }
-	
 private:
-	struct Mapping
+	struct ScopeData
 	{
-						Mapping() : fName(0), fVar(kIllegalVar) {}
-						Mapping(const Symbol *name, int var, bool a) : fName(name), fVar(var), fArray(a) {}
-						
+		ScopeData() : fName(0), fVar(kIllegalVar), fArray(0), fPtr(0), fStack(0) {}
+		ScopeData(const Symbol *name, int var, bool a, bool ptr, bool stack) :
+                  fName(name), fVar(var), fArray(a), fPtr(ptr), fStack(stack) {}
+
 		const Symbol *	fName;
-		int				fVar;
-		bool			fArray;
+		int	fVar;
+		bool	fArray;
+                bool    fPtr;
+                bool    fStack;
 	};
-	
-	int					Lookup1(const Symbol *name, bool *array = 0);
-	
-	vector<Mapping>		fBindings;
+
+	int	Lookup1(const Symbol *name, bool *array = 0, bool *ptr = 0, bool *stack = 0);
+
+	vector<ScopeData>	fBindings;
 };
 
 #endif
