@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 2000 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __ScopeStmt_h
@@ -21,7 +25,9 @@
 #include "Stmt.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class ScopeStmt : public ChainStmt
 {
