@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "Stmt.h"
@@ -37,7 +41,7 @@ bool Stmt::IsDescendantOf(const Stmt *ancestor) const
 		if (s==ancestor) return true;
 		s = s->GetParent();
 	}
-	
+
 	return false;
 }
 
@@ -53,9 +57,9 @@ void Stmt::Emit(Bytecode &b)
 	// this is where to hook general-purpose emit code that
 	// applies to all statements.  For now, just add a source tag and
 	// then call EmitActual() which is virtual and does all the work
-	
+
 	b.AddSourceTag(RCX_SourceTag::kNormal, fLoc);
-		
+
 	EmitActual(b);
 }
 
@@ -65,7 +69,7 @@ Stmt *Stmt::Clone(Mapping *b) const
 {
 	// this is where to hook general-purpose clone code that
 	// applies to all statements.
-	
+
 	// for now, just copy location information after using
 	// CloneActual (which is virtual) to make the actual clone
 
@@ -103,7 +107,7 @@ BinaryStmt::BinaryStmt(Stmt *s1, Stmt *s2) :
 	{
 		// this is a hack to get fPrimary and fSecondary linked together
 		PListSS<Stmt> list;
-		
+
 		list.InsertHead(s2);
 		list.InsertHead(s1);
 	}
@@ -124,15 +128,18 @@ Stmt *BinaryStmt::GetChildren()
 
 
 #ifdef DEBUG
-#include <stdio.h>
+#include <cstdio>
 #include <typeinfo>
 
+using std::printf;
+using std::putchar;
+
 void DumpStmt(Stmt *s, int tab)
 {
 	for(int i=0; i<tab; i++)
 		putchar(' ');
 	printf("%s  %08x\n", typeid(*s).name(), s);
-	
+
 	for(Stmt*c = s->GetChildren(); c; c=c->GetNext())
 	{
 		DumpStmt(c, tab + 2);
