@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __Stmt_h
@@ -29,7 +33,9 @@
 #include "LocationNode.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class Bytecode;
 class CheckState;
@@ -39,7 +45,7 @@ class Expr;
 /*
  * Stmt is the abstract base class for all program statements
  */
- 
+
 class Stmt :  public PLinkS<Stmt>, public AutoFree
 {
 public:
@@ -56,13 +62,13 @@ public:
 
 			// flag used to force statement to be emitted (not optimized out)
 	bool	GetMustEmit() const	{ return fMustEmit; }
-	void	SetMustEmit(bool b)	{ fMustEmit = b; }	
+	void	SetMustEmit(bool b)	{ fMustEmit = b; }
 
 			// overall emit which will call the virtual EmitActual
 			void	Emit(Bytecode &b);
 
 	virtual void	EmitActual(Bytecode &b) = 0;
-	
+
 			Stmt*	Clone(Mapping *b) const;
 	virtual Stmt*	CloneActual(Mapping *b) const = 0;
 
@@ -72,7 +78,7 @@ public:
 
 protected:
 	void	Adopt(Stmt *c)	{ if (c) c->fParent = this; }
-	
+
 	LexLocation	fLoc;
 	Stmt*		fParent;
 	bool		fMustEmit;
@@ -93,7 +99,7 @@ public:
 
 /*
  * ChainStmt is an abstract base class for statements that contain
- * a single child.  
+ * a single child.
  */
 
 class ChainStmt : public Stmt
@@ -106,7 +112,7 @@ public:
 
 	Stmt*			GetBody()	{ return fBody; }
 	const Stmt*		GetBody() const	{ return fBody; }
-	
+
 protected:
 	void			SetBody(Stmt *s)	{ fBody=s; Adopt(s); }
 
@@ -125,7 +131,7 @@ class BinaryStmt : public Stmt
 public:
 					BinaryStmt(Stmt *s1, Stmt *s2=0);
 					~BinaryStmt();
-	
+
 	virtual Stmt*	GetChildren();
 
 protected:
@@ -133,10 +139,10 @@ protected:
 	const Stmt*		GetPrimary() const	{ return fPrimary; }
 	Stmt*			GetSecondary() { return fSecondary; }
 	const Stmt*		GetSecondary() const	{ return fSecondary; }
-	
+
 private:
 	Stmt*			fPrimary;
-	Stmt*			fSecondary;	
+	Stmt*			fSecondary;
 };
 
 
@@ -144,7 +150,7 @@ private:
 template <class OP> void Apply(Stmt *base, OP &op)
 {
 	Stmt *s;
-	
+
 	if (!op(base)) return;
 
 	for(s=base->GetChildren(); s; s=s->GetNext())
