@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __SwitchStmt_h
@@ -25,20 +29,22 @@
 #include "Expr.h"
 #endif
 
-#include <vector.h>
+#include <vector>
+
+using std::vector;
 
 class SwitchStmt : public ChainStmt
 {
 public:
 			SwitchStmt(Expr *e, Stmt *s);
 			~SwitchStmt();
-	
+
 	virtual	void	EmitActual(Bytecode &b);
 
 	Stmt*	CloneActual(Mapping *b) const;
 	virtual void	GetExprs(vector<Expr*> & v) const;
 
-private:	
+private:
 	Expr*		fSelector;
 };
 
@@ -50,13 +56,13 @@ public:
 					fSelector(selector),
 					fDefaultLabel(defaultLabel)
 					{}
-				
+
 	bool		ContainsCase(int v);
 	void		AddCase(int v)			{ fCases.push_back(v); }
 
 	RCX_Value	GetSelector() const		{ return fSelector; }
 	int			GetDefaultLabel() const	{ return fDefaultLabel; }
-	
+
 private:
 	RCX_Value	fSelector;
 	int			fDefaultLabel;
