@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -19,25 +23,25 @@
  * evalutae correctly to type 2.  All other expressions evaluate to type 0
  * even if they are from some other non-constant source (sensor, random, etc)
  *
- * Fixing this would require either adding RTTI code, or preferably adding 
+ * Fixing this would require either adding RTTI code, or preferably adding
  * another virtual method to the Expr hierarchy that returns the typecode of
  * the expression.
  */
- 
+
 
 #ifndef __TypeExpr_h
 #define __TypeExpr_h
 
-#include "UnaryBaseExpr.h"
+#include "NodeExpr.h"
 
 
-class TypeExpr : public UnaryBaseExpr
+class TypeExpr : public NodeExpr
 {
 public:
-		TypeExpr(Expr *e) : UnaryBaseExpr(e) {}
+		TypeExpr(Expr *e) : NodeExpr(e) {}
 
 	virtual Expr*		Clone(Mapping *b) const;
-	
+
 	virtual RCX_Value	EmitAny_(Bytecode &b) const;
 
 	virtual bool		PromiseConstant() const	{ return true; }
