@@ -12,24 +12,35 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #include "UnaryExpr.h"
 #include "parser.h"
 #include "Bytecode.h"
 #include "RCX_Cmd.h"
+#include "Program.h"
 
 static RCX_VarCode GetUnaryCode(int op);
 
 
 static RCX_VarCode GetUnaryCode(int op)
 {
+        const RCX_Target *t = gProgram->GetTarget();
 	switch(op)
 	{
 		case ABS:
 			return kRCX_AbsVar;
 		case SIGN:
 			return kRCX_SgnVar;
+                case '~':
+                        if (t->fType == kRCX_SwanTarget)
+                           return kRCX_NotVar;
+                        else
+                           return kRCX_IllegalVar;
 		default:
 			return kRCX_IllegalVar;
 	}
@@ -46,7 +57,7 @@ Expr* UnaryExpr::Clone(Mapping *b) const
 bool UnaryExpr::Evaluate(int &value) const
 {
 	if (!Get(0)->Evaluate(value)) return false;
-	
+
 	switch(fOp)
 	{
 		case '~':
@@ -73,10 +84,10 @@ bool UnaryExpr::Evaluate(int &value) const
 
 RCX_Value UnaryExpr::EmitAny_(Bytecode &b) const
 {
-	RCX_Cmd cmd;	
+	RCX_Cmd cmd;
 	RCX_Value ea;
 	int dst;
-	
+
 	ea = Get(0)->EmitMath(b);
 	if (ea == kIllegalEA) return ea;
 
@@ -92,10 +103,10 @@ RCX_Value UnaryExpr::EmitAny_(Bytecode &b) const
 		if (dst < 0)
 			return kIllegalEA;
 	}
-	
+
 	cmd.MakeVar(GetUnaryCode(fOp), dst, ea);
 	b.Add(cmd);
-	
+
 	// return the ea
 	return RCX_VALUE(kRCX_VariableType, dst);
 }
@@ -105,7 +116,7 @@ bool UnaryExpr::EmitTo_(Bytecode &b, int dst) const
 {
 	RCX_Value ea;
 	RCX_Cmd cmd;
-	
+
 	ea = Get(0)->EmitMath(b);
 	if (ea == kIllegalEA) return false;
 
@@ -124,6 +135,6 @@ bool UnaryExpr::EmitSide_(Bytecode &b) const
 
 bool UnaryExpr::NeedsConstant(int op)
 {
-	return GetUnaryCode(op) == kRCX_IllegalVar; 
+	return GetUnaryCode(op) == kRCX_IllegalVar;
 }
 
