@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 2000 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 /*
@@ -36,17 +40,17 @@
  *
  * In cases where a single task is known to be in execution
  * (kTaskMode or kSingleSubMode) allocation is allowed to
- * overflow from the local pool to the global pool.  
+ * overflow from the local pool to the global pool.
  *
  * Vars allocated from the global pool may be re-used within the
  * same Begin()/End() session, but then become permanently
  * allocated after End().  In contrast, the local pool is refreshed
- * each time Begin() is called - in the case of tasks this is 
+ * each time Begin() is called - in the case of tasks this is
  * justified by the fact that each task has its own local vars.
  * For subs, this is because the true variable allocation is
  * done within the calling task, and this is checked for conflicts
  * by CheckAvailable().
- * 
+ *
  * This strategy ensures that subs always use the bottom-most
  * local vars (overflow to globals in the case of a sub called
  * by only 1 task).  Allocations for a task use up locals from
@@ -60,7 +64,8 @@
 #include "Variable.h"
 
 #ifdef DEBUG
-#include <stdio.h>
+#include <cstdio>
+using std::printf;
 //#define DEBUG_VARS
 #endif
 
@@ -85,9 +90,9 @@ VarAllocator::~VarAllocator()
 bool VarAllocator::Reserve(int v)
 {
 	if (!IsLegal(v)) return false;
-	
+
 	if (fStates[v] != kFree) return false;
-	
+
 	fStates[v] = kReserved;
 	return true;
 }
@@ -96,7 +101,7 @@ bool VarAllocator::Reserve(int v)
 int VarAllocator::Allocate(bool temp, bool canUseLocals, int count)
 {
 	int v = kIllegalVar;
-	
+
 	switch(fMode)
 	{
 		case kGlobalMode:
@@ -130,7 +135,7 @@ int VarAllocator::Allocate(bool temp, bool canUseLocals, int count)
 #endif
 		}
 	}
-	
+
 	return v;
 }
 
@@ -162,7 +167,7 @@ void VarAllocator::ReleaseTemp(int v)
 void VarAllocator::Begin(int mode)
 {
 	fMode = mode;
-	
+
 	// always start with a clean set of locals
 	for(int i=fLocalStart; i<fMaxVars; ++i) {
 		if (fStates[i] != kReserved)
@@ -180,8 +185,8 @@ int VarAllocator::End()
 		if ((fStates[i] == kDirty) || (fStates[i] == kTemp))
 			fStates[i] = kUsed;
 	}
-	
-	
+
+
 	// now figure out the local mask
 	int localMask = 0;
 	for(int i=fLocalStart; i<fMaxVars; ++i)
@@ -189,9 +194,9 @@ int VarAllocator::End()
 		if (fStates[i] != kFree && fStates[i] != kReserved)
 			localMask |= 1 << (i-fLocalStart);
 	}
-	
+
 	fMode = kGlobalMode;
-	
+
 	return localMask;
 }
 
@@ -203,7 +208,7 @@ bool VarAllocator::CheckLocalMask(int localMask) const
 			if (fStates[i] >= kUsed) return false;
 		}
 	}
-	
+
 	return true;
 }
 
@@ -223,7 +228,7 @@ int VarAllocator::FindUnused(int start, int end, int count)
 		for(int i=start-count; i>=end; --i)
 			if (CheckAvailable(i, count)) return i;
 	}
-	
+
 	return kIllegalVar;
 }
 
@@ -234,6 +239,6 @@ bool VarAllocator::CheckAvailable(int first, int count) const
 	{
 		if (fStates[first++] >= kUsed) return false;
 	}
-	
+
 	return true;
 }
