@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __WhileStmt_h
@@ -30,13 +34,12 @@ class WhileStmt : public ChainStmt
 public:
 			WhileStmt(Expr *c, Stmt *s);
 			~WhileStmt();
-	
-	void	ComputeNullable();
+
 	void	EmitActual(Bytecode &b);
-	Stmt*	Clone(Mapping *b) const;
+	Stmt*	CloneActual(Mapping *b) const;
 	virtual void	GetExprs(vector<Expr*> & v) const	{ v.push_back(fCondition); }
 
-private:	
+private:
 	Expr*	fCondition;
 };
 
