@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 
@@ -36,6 +40,7 @@ class Condition;
 class Symbol;
 class CaseStmt;
 class FunctionDef;
+class Fragment;
 class ConstField;
 class DeclareStmt;
 class AssignStmt;
@@ -54,6 +59,10 @@ extern int GetLValue(const Expr *e);
 extern Stmt* MakeCall(Symbol *name, const struct LexLocation &loc);
 
 extern CaseStmt* MakeCaseStmt(const Expr *e, const struct LexLocation &loc);
+extern void DefineSubArg(Fragment *f, const Symbol *name, int type);
+extern Fragment* CreateSubroutine(Fragment *f, Symbol *name, Stmt *body);
+extern Fragment* BeginSubWithParams(Fragment *f, Symbol *name);
+extern void EndSubWithParams(Fragment *f, Stmt *body, LocationNode *start, LocationNode *end);
 extern void DefineArg(FunctionDef *f, const Symbol *name, int type);
 extern FunctionDef* BeginFunction(FunctionDef *f, const Symbol *name, bool listing);
 extern void EndFunction(FunctionDef *f, Stmt *body, LocationNode *start, LocationNode *end);
@@ -61,10 +70,14 @@ extern ConstField* MakeConstField(Expr *e);
 extern Expr *MakeVarExpr(const Symbol *name, LocationNode *loc);
 extern Expr *MakeTaskIdExpr(LocationNode *ln);
 extern Expr *MakeArrayExpr(const Symbol *name, LocationNode *loc, Expr *index);
+extern Expr *MakeAddrOfExpr(const Symbol *name, LocationNode *ln, Expr *index);
+extern Expr *MakeDerefExpr(const Symbol *name, LocationNode *ln);
+extern Expr *MakeIncDecExpr(Expr *lhs, bool inc, bool pre, const LexLocation &loc);
 extern Stmt* MakeAcquireStmt(const Expr *e, Stmt *body, Stmt *handler, LocationNode *ln);
 extern Stmt* MakeCatchStmt(const Expr *e, Stmt *body, LocationNode *ln);
-extern DeclareStmt *MakeDeclareStmt(const Symbol *name, LocationNode *loc, Expr *arraySize);
+extern DeclareStmt *MakeDeclareStmt(const Symbol *name, LocationNode *loc, Expr *arraySize, bool ptr, bool stack);
 extern void CheckLValue(Expr *lval);
+extern Stmt* MakeAssignStmt(Expr *lhs, int op, Expr *rhs);
 extern Stmt* MakeAssign2Stmt(Expr *lhs, int op, Expr *rhs);
 
 extern void BeginScope();
