@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __parser_h
@@ -41,7 +45,7 @@ int	yylex(YYSTYPE &tokenVal);
 #endif
 
 #ifndef _STDIO_H
-#include <stdio.h>
+#include <cstdio>
 #endif
 
 // from parse.tab.c
