@@ -12,13 +12,20 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 2000 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __CmdLine_h
 #define __CmdLine_h
 
-#include <stdlib.h>
-#include <vector.h>
+#include <cstdlib>
+#include <vector>
+
+using std::atoi;
+using std::vector;
 
 class CmdLine
 {
@@ -30,7 +37,7 @@ public:
 	void		Add(int argc, const char * const *argv);	// add multiple args
 
 	void		Parse(const char *line, int skip = 0);	// parse line and add args
-	
+
 	int			Remain() const	{ return fArgs.size() - fPos; }
 	const char *Next()			{ return fArgs[fPos++]; }
 	int			NextInt()		{ return atoi(Next()); }
