@@ -12,9 +12,14 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1999 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
-#include <string.h>
+#include <cstring>
+
 #if defined(__MWERKS__) && (!__MACH__)
 #include <stat.h>
 #else
@@ -22,13 +27,20 @@
 #endif
 #include "DirList.h"
 
+using std::strcat;
+using std::strlen;
+using std::size_t;
+
+#ifdef DEBUG
+using std::strcpy;
+#endif
 
 DirList::~DirList()
 {
 	Entry *e;
-	
+
 	while((e=fEntries.RemoveHead()) != 0)
-		delete e;	
+		delete e;
 }
 
 
@@ -36,7 +48,7 @@ void DirList::Add(const char *path)
 {
 	// ignore NULL or empty path
 	if (path==0 || *path==0) return;
-	
+
 	Entry *e = new Entry(path);
 	fEntries.InsertTail(e);
 }
@@ -45,7 +57,7 @@ void DirList::Add(const char *path)
 bool DirList::Find(const char *filename, char *pathname)
 {
 	struct stat stat_buf;
-	
+
 	strcpy(pathname, filename);
 	if (stat(pathname, &stat_buf) == 0)
 		return true;
@@ -58,8 +70,8 @@ bool DirList::Find(const char *filename, char *pathname)
 		{
 			return true;
 		}
-	}	
-	
+	}
+
 	return false;
 }
 
@@ -67,10 +79,10 @@ bool DirList::Find(const char *filename, char *pathname)
 DirList::Entry::Entry(const char *path)
 {
 	size_t length = strlen(path);
-	
+
 	fPath = new char[length+2]; // leave room for terminating delimiter
 	strcpy(fPath, path);
-	
+
 	// should we append the delimiter?
 	if (path[length-1] != DIR_DELIMITER)
 	{
