@@ -22,8 +22,8 @@
  * environment variables.
  */
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 
 #if defined(__cplusplus) && defined(_MSL_USING_NAMESPACE)
 namespace std {
@@ -60,11 +60,11 @@ char* getenv(const char *name)
 	}
 #endif
 	int i;
-	
+
 	for(i=0; i<kEnvCount; i++)
 		if (strcmp(sEnvironment[2*i], name)==0)
 			return sEnvironment[2*i+1];
-	
+
 	return 0;
 }
 
