@@ -12,17 +12,22 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifdef WIN32
 #include <windows.h>
 #endif
 
-#include <stdio.h>
-#include <string.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <time.h>
+#include <cstdio>
+#include <cstring>
+#include <cctype>
+#include <cstdlib>
+#include <ctime>
+
 #include "Program.h"
 #include "RCX_Image.h"
 #include "RCX_Link.h"
@@ -41,6 +46,13 @@
 #include "CmdLine.h"
 #include "version.h"
 
+using std::fopen;
+using std::printf;
+using std::time_t;
+using std::localtime;
+using std::tm;
+
+
 // use this to check for memory leaks in the compiler
 //#define CHECK_LEAKS
 
@@ -70,20 +82,20 @@ FILE *gErrorStream = stderr;
 class AutoLink : public RCX_Link
 {
 public:
-				AutoLink() : fSerialPort(0), fOpen(false) {}
-				~AutoLink()	{ Close(); }
+	AutoLink() : fSerialPort(0), fOpen(false) {}
+	~AutoLink()	{ Close(); }
 
 	RCX_Result	Open();
 	void		Close();
 	RCX_Result	Send(const RCX_Cmd *cmd, bool retry=true);
-	
+
 	void		SetSerialPort(const char *sp)	{ fSerialPort = sp; }
 
 	bool		DownloadProgress(int soFar, int total);
 
 private:
 	const char*	fSerialPort;
-	bool		fOpen;		
+	bool		fOpen;
 };
 
 
@@ -91,8 +103,8 @@ private:
 class MyCompiler : public Compiler, public ErrorHandler
 {
 public:
-				MyCompiler()	 {}
-				
+	MyCompiler()	 {}
+
 	Buffer *CreateBuffer(const char *name);
 
 	void	AddError(const Error &e, const LexLocation *loc);
@@ -157,7 +169,8 @@ static const char *sTargetNames[] =
 	"cm",
 	"scout",
 	"rcx2",
-	"spy"
+	"spy",
+        "swan"
 };
 
 
@@ -170,7 +183,8 @@ struct Request
 	bool	fSourceListing;
 	bool	fDownload;
 	bool	fBinary;
-	int		fFlags;
+        bool    fGenLASM;
+	int	fFlags;
 };
 
 static int GetActionCode(const char *arg);
@@ -183,7 +197,7 @@ static char *CreateFilename(const char *source, const char *oldExt, const char *
 static const char *LeafName(const char *filename);
 static int CheckExtension(const char *s1, const char *ext);
 static RCX_Image *Compile(const char *sourceFile,  int flags);
-static bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource);
+static bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource, bool generateLASM);
 static RCX_Result Download(RCX_Image *image);
 static RCX_Result UploadDatalog(bool verbose);
 static RCX_Result DownloadFirmware(const char *filename, bool fast);
@@ -203,6 +217,7 @@ AutoLink gLink;
 RCX_TargetType gTargetType = kRCX_RCXTarget;
 bool gVerbose = false;
 int gTimeout = 0;
+bool gQuiet = false;
 
 
 int main(int argc, char **argv)
@@ -212,8 +227,8 @@ int main(int argc, char **argv)
 	// add any default include paths
 	gMyCompiler.AddDir(getenv(kOldIncludePathEnv));
 	gMyCompiler.AddDir(getenv(kNewIncludePathEnv));
-	
-	result = ProcessCommandLine(argc, argv);	
+
+	result = ProcessCommandLine(argc, argv);
 	PrintError(result);
 
 	gLink.Close();
@@ -221,12 +236,12 @@ int main(int argc, char **argv)
 	if (gErrorStream != stderr &&
 		gErrorStream != stdout)
 		fclose(gErrorStream);
-	
+
 #ifdef DEBUG_NEW
 	printf("%d allocations, %d total bytes, %d max\n", gDebugNewAllocCount, gDebugNewAllocCurr, gDebugNewAllocMax);
 #endif
-	
-	
+
+
 	return RCX_ERROR(result) ? result : 0;
 }
 
@@ -239,14 +254,14 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 	CmdLine args;
 	RCX_Result result = kRCX_OK;
 	RCX_Cmd cmd;
-	
+
 	// first add environment options
 	args.Parse(getenv(kOptionsEnv));
 
 	// add all command line args after the first one
 #ifdef WIN32
 	// For Win32, bypass the argc/argv array and get the raw command line
-	// This is for backwards compatability with RcxCC which doesn't like its
+	// This is for backwards compatability with BricxCC which doesn't like its
 	// args to be escaped by the runtime
 	#pragma unused(argc, argv)
 	args.Parse(GetCommandLineA(), 1);
@@ -254,13 +269,13 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 	if (argc > 1)
 		args.Add(argc-1, argv+1);
 #endif
-	
+
 	// process the args
 	while(args.Remain() && !RCX_ERROR(result))
 	{
 		const char* a=args.Next();
 		bool isOption = (a[0] == '-');
-		
+
 #ifdef WIN32
 		if (a[0]=='/') isOption = true;
 #endif
@@ -278,7 +293,7 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 				if (!optionsOK) return kUsageError;
 				code = a[1];
 			}
-			
+
 			switch(code)
 			{
 				// options
@@ -306,6 +321,9 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 				case 's':
 					req.fSourceListing = true;
 					break;
+				case 'c':
+					req.fGenLASM = true;
+                                        break;
 				case 'O':
 					if  (*(a+2)=='\0') return kUsageError;
 					req.fOutputFile = a+2;
@@ -318,6 +336,21 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 					if  (*(a+2)=='\0') return kUsageError;
 					result = SetTarget(a+2);
 					break;
+                                case 'x':
+                                        gLink.SetOmitHeader(true);
+                                        break;
+//                                case 'p':
+//                                        if  (*(a+2)=='\0') return kUsageError;
+//                                        gLink.SetRCXProgramChunkSize(atoi(a+2));
+//                                        break;
+                                case 'f':
+                                        if  (*(a+2)=='\0') return kUsageError;
+                                        gLink.SetRCXFirmwareChunkSize(atoi(a+2));
+                                        break;
+                                case 'w':
+                                        if  (*(a+2)=='\0') return kUsageError;
+                                        gLink.SetDownloadWaitTime(atoi(a+2));
+                                        break;
 				case 'U':
 					if  (*(a+2)=='\0') return kUsageError;
 					Compiler::Get()->Undefine(a+2);
@@ -341,6 +374,9 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 				case 'v':
 					gVerbose = true;
 					break;
+                                case 'q':
+                                        gQuiet = true;
+                                        break;
 
 				// actions
 				case kCompileStdinCode:
@@ -402,11 +438,11 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 						result = SendRemote(event, repeat);
 					}
 					break;
-				
+
 				case kApiCode:
 					PrintApi(req.fFlags & Compiler::kCompat_Flag);
 					break;
-					
+
 				case kHelpCode:
 					PrintUsage();
 					break;
@@ -430,10 +466,10 @@ RCX_Result ProcessCommandLine(int argc, char ** argv)
 		else
 			return kUsageError;
 	}
-	
+
 	// check if we did anything (compile and/or actions)
 	if (optionsOK) return kUsageError;
-	
+
 	return result;
 }
 
@@ -474,9 +510,9 @@ RCX_Result SetTarget(const char *name)
 			gTargetType = kRCX_ScoutTarget;
 			break;
 		default:
-			return kUsageError;		
+			return kUsageError;
 	}
-	
+
 	return kRCX_OK;
 }
 
@@ -486,12 +522,12 @@ RCX_Result SetWatch(const char *timeSpec)
 	int hour;
 	int minute;
 	RCX_Cmd cmd;
-	
+
 	if (strcmp(timeSpec, "now")==0)
 	{
 		time_t t;
 		struct tm *tmp;
-		
+
 		time(&t);
 		tmp = localtime(&t);
 		hour = tmp->tm_hour;
@@ -503,7 +539,7 @@ RCX_Result SetWatch(const char *timeSpec)
 		hour = t / 100;
 		minute = t % 100;
 	}
-	
+
 	return gLink.Send(cmd.Set(kRCX_SetWatchOp, (UByte)hour, (UByte)minute));
 }
 
@@ -514,7 +550,7 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	RCX_Result result = kRCX_OK;
 	bool ok = true;
 	bool compiled = false;
-	
+
 	if (sourceFile && (req.fBinary || CheckExtension(sourceFile, kRCXFileExtension)))
 	{
 		// load RCX image file
@@ -532,22 +568,22 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 		// compile file
 		compiled = true;
 		image = Compile(sourceFile, req.fFlags);
-		
+
 		if (!image)
 		{
 			int errors = ErrorHandler::Get()->GetErrorCount();
-			
+
 			if (errors)
 				fprintf(gErrorStream, "# %d error%s during compilation\n", errors, errors==1 ? "" : "s");
 			return kQuietError;
 		}
-		
+
 		const char *outputFile = req.fOutputFile;
 		char *newFilename = 0;
-		
+
 		if (!req.fDownload && !req.fListing && !req.fOutputFile && sourceFile)
 			outputFile = newFilename = CreateFilename(LeafName(sourceFile), kNQCFileExtension, kRCXFileExtension);
-		
+
 		if (outputFile)
 		{
 			if (!image->Write(outputFile))
@@ -556,7 +592,7 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 				ok = false;
 			}
 		}
-		
+
 		if (newFilename)
 			delete [] newFilename;
 	}
@@ -564,7 +600,7 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	// generate the listing
 	if (req.fListing)
 	{
-		if (!GenerateListing(image, req.fListFile, compiled && req.fSourceListing))
+		if (!GenerateListing(image, req.fListFile, compiled && req.fSourceListing, req.fGenLASM))
 			ok = false;
 	}
 
@@ -584,16 +620,16 @@ RCX_Result ProcessFile(const char *sourceFile, const Request &req)
 	// the failure
 	if (result==kRCX_OK && !ok)
 		result = kQuietError;
-		
+
 	delete image;
 	return result;
 }
 
 
-bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource)
+bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource, bool generateLASM)
 {
 	FILE *fp;
-	
+
 	if (filename)
 	{
 		fp = fopen(filename, "w");
@@ -607,29 +643,29 @@ bool GenerateListing(RCX_Image *image, const char *filename, bool includeSource)
 		fp = stdout;
 
 	RCX_StdioPrinter dst(fp);
-	image->Print(&dst, includeSource ? Compiler::Get() : 0);
-	
+	image->Print(&dst, includeSource ? Compiler::Get() : 0, generateLASM);
+
 	if (fp != stdout)
 		fclose(fp);
 
-	return true;	
+	return true;
 }
 
 
 RCX_Result Download(RCX_Image *image)
 {
-	RCX_Result result = kRCX_OK;
+	RCX_Result result;
 	RCX_Cmd cmd;
-	
+
 	fprintf(STDERR, "Downloading Program:");
 	result = gLink.Open();
 	if (result != kRCX_OK) goto ErrorReturn;
-	
+
 	result = image->Download(&gLink);
-	if (result != kRCX_OK) goto ErrorReturn;	
-	
+	if (result != kRCX_OK) goto ErrorReturn;
+
 	fprintf(STDERR, "complete\n");
-	
+
 	result = gLink.GetBatteryLevel();
 	if (!RCX_ERROR(result))
 	{
@@ -638,9 +674,9 @@ RCX_Result Download(RCX_Image *image)
 		if (result < lowBatt)
 			fprintf(STDERR, "*** Warning: batteries are low ***\n");
 	}
-	
+
 	return kRCX_OK;
-	
+
 ErrorReturn:
 	fprintf(STDERR, "error\n");
 	return result;
@@ -659,7 +695,7 @@ RCX_Image *Compile(const char *sourceFile, int flags)
 			fprintf(gErrorStream, "Error: could not open file \"%s\"\n", sourceFile);
 			return nil;
 		}
-		
+
 		mainBuf = new Buffer();
 		mainBuf->Create(sourceFile, fp);
 		fclose(fp);
@@ -676,7 +712,7 @@ RCX_Image *Compile(const char *sourceFile, int flags)
 	int t;
 	TokenVal v;
 	LexLocation loc;
-	
+
 #if TEST_LEXER > 1
 	while((t=gPreProc->Get(v)) != 0)
 #else
@@ -690,12 +726,12 @@ RCX_Image *Compile(const char *sourceFile, int flags)
 
 	LexCurrentLocation(loc);
 	printf("%3d (%2d) : EOF\n", loc.fOffset, loc.fLength);
-	
+
 	return 0;
 #else
 	Buffer *b = new Buffer();
 	b->Create(mainBuf->GetName(), mainBuf->GetData(), mainBuf->GetLength());
-	
+
 	return Compiler::Get()->Compile(mainBuf, getTarget(gTargetType), flags);
 #endif
 }
@@ -706,24 +742,24 @@ RCX_Result UploadDatalog(bool verbose)
 	RCX_Log log;
 	RCX_Result result;
 	int i;
-	
+
 	fprintf(STDERR, "Uploading Datalog");
-	
+
 	result = gLink.Open();
 	if (RCX_ERROR(result)) return result;
-	
+
 	result = log.Upload(&gLink);
 	if (RCX_ERROR(result)) return result;
-	
+
 	fprintf(STDERR, "\n");
-	
+
 	for(i=0; i<log.GetLength(); i++)
 	{
 		char line[256];
 		log.SPrintEntry(line, i, verbose);
 		printf("%s\n", line);
 	}
-	
+
 	return kRCX_OK;
 }
 
@@ -732,17 +768,17 @@ RCX_Result ClearMemory()
 {
 	RCX_Result result;
 	RCX_Cmd cmd;
-	
+
 	// halt all tasks
 	result = gLink.Send(cmd.Set(kRCX_StopAllOp));
 	if (RCX_ERROR(result)) return result;
-	
+
 	for(UByte p=0; p<5; p++)
 	{
 		// select and delete program
 		result = gLink.Send(cmd.Set(kRCX_SelectProgramOp, p));
 		if (RCX_ERROR(result)) return result;
-	
+
 		result = gLink.Send(cmd.MakeDeleteSubs());
 		if (RCX_ERROR(result)) return result;
 
@@ -762,17 +798,17 @@ RCX_Result DownloadFirmware(const char *filename, bool fast)
 	bool ok;
 	RCX_Result result;
 	ULong rom, ram;
-	
+
 	fp = fopen(filename, "rb");
 	if (!fp)
 	{
 		fprintf(STDERR, "Error: could not open file \'%s\'\n", filename);
 		return kQuietError;
 	}
-	
+
 	ok = srec.Read(fp, kMaxFirmware);
 	fclose(fp);
-	
+
 	if (!ok)
 	{
 		fprintf(STDERR, "Error: \'%s\' is not a valid S-Record file\n", filename);
@@ -802,14 +838,14 @@ RCX_Result SendRawCommand(const char *text, bool retry)
 	int length = (int)strlen(text);
 	RCX_Cmd cmd;
 	RCX_Result result;
-	
+
 	// we need an even number of chars in text
 	if (length & 1) return kUsageError;
-	
+
 	// determine actual length of command
 	length /= 2;
 	cmd.SetLength(length);
-	
+
 	for(int i=0; i<length; i++)
 	{
 		int byte = SRecord::ReadHexByte(text);
@@ -817,7 +853,7 @@ RCX_Result SendRawCommand(const char *text, bool retry)
 		cmd[i] = (UByte) byte;
 		text+=2;
 	}
-	
+
 	result = gLink.Send(&cmd, retry);
 
 	if (result > 0)
@@ -826,7 +862,7 @@ RCX_Result SendRawCommand(const char *text, bool retry)
 			printf("%02x ", gLink.GetReplyByte(i));
 		printf("\n");
 	}
-	
+
 	return result;
 }
 
@@ -835,24 +871,24 @@ RCX_Result SendRemote(const char *event, int repeat)
 {
 	RCX_Cmd cmd;
 	int low, high;
-	
+
 	if (repeat == 0) return kUsageError;
-	
+
 	if (strlen(event) != 4)
 		return kUsageError;
-	
+
 	high = SRecord::ReadHexByte(event);
 	low = SRecord::ReadHexByte(event+2);
 	if (high==-1 || low==-1) return kUsageError;
-	
+
 
 	cmd.Set(kRCX_Remote, low, high);
-	
+
 	while(repeat--)
 	{
 		gLink.Send(&cmd, false);
 	}
-	
+
 	return kRCX_OK;
 }
 
@@ -869,7 +905,7 @@ char *CreateFilename(const char *source, const char *oldExt, const char *newExt)
 	filename = new char[n + newExtLen + 1];
 	memcpy(filename, source, n);
 	strcpy(filename + n, newExt);
-	
+
 	return filename;
 }
 
@@ -879,12 +915,12 @@ int CheckExtension(const char *s1, const char *ext)
 	size_t slen = strlen(s1);
 	size_t plen = strlen(ext);
 	unsigned i;
-	
+
 	if (slen < plen) return 0;
-	
+
 	for(i=0; i<plen; i++)
 		if (tolower(s1[slen-plen+i]) != tolower(ext[i])) return 0;
-	
+
 	return 1;
 }
 
@@ -909,7 +945,7 @@ const char *LeafName(const char *filename)
 
 		--ptr;
 	}
-	
+
 	// we either stopped at the char before the first, or at
 	// the delimiter - either way return pointer to next char
 	return ptr+1;
@@ -919,20 +955,20 @@ const char *LeafName(const char *filename)
 RCX_Result SetErrorFile(const char *filename)
 {
 	FILE *fp;
-	
+
 	if (*filename==0)
 	{
 		gErrorStream = stdout;
 		return kRCX_OK;
 	}
-	
+
 	fp = fopen(filename, "w");
 	if (!fp)
 	{
 		fprintf(STDERR, "Error: could not open error file \'%s\'\n", filename);
 		return kQuietError;
 	}
-	
+
 	gErrorStream = fp;
 	return kRCX_OK;
 }
@@ -945,13 +981,13 @@ RCX_Result RedirectOutput(const char *filename)
 		fprintf(STDERR, "Error: -R requires a filename\n");
 		return kQuietError;
 	}
-	
+
 	if (!freopen(filename, "w", stdout))
 	{
 		fprintf(STDERR, "Error: could not open output file \'%s\'\n", filename);
 		return kQuietError;
 	}
-	
+
 	return kRCX_OK;
 }
 
@@ -967,12 +1003,12 @@ void DefineMacro(const char *text)
 		char *name = new char[length+1];
 		memcpy(name, text, (size_t)length);
 		name[length] = 0;
-		
+
 		Compiler::Get()->Define(name, body+1);
-		
+
 		delete [] name;
 	}
-	else	
+	else
 	{
 		Compiler::Get()->Define(text);
 	}
@@ -992,11 +1028,14 @@ void PrintError(RCX_Result error, const char *filename)
 {
 	const char *targetName = getTarget(gTargetType)->fName;
 	if (!filename) filename = "?";
-	
+
 	if (error >= 0) return;
-	
+
 	switch(error)
 	{
+                case kRCX_RequestError:
+                        fprintf(STDERR, "Request error\n");
+                        break;
 		case kRCX_OpenSerialError:
 			fprintf(STDERR, "Could not open serial port or USB device\n");
 			break;
@@ -1026,15 +1065,15 @@ void PrintError(RCX_Result error, const char *filename)
 			break;
 		case kQuietError:
 			break;
-		
+
 		case kRCX_PipeModeError:
 			fprintf(STDERR,"USB driver does not support -firmfast, CyberMaster, or Spybotics\n");
 			break;
-			
+
 		case kRCX_USBUnsupportedError:
 			fprintf(STDERR,"USB Tower not supported\n");
 			break;
-			
+
 		case kRCX_GhostNotFoundError:
 			fprintf(STDERR,"Ghost libraries are not installed properly\n");
 			break;
@@ -1048,60 +1087,67 @@ void PrintVersion()
 {
 	fprintf(STDERR,"nqc version %s (built "__DATE__", " __TIME__")\n",
 		VERSION_STRING);
-	fprintf(STDERR,"     Copyright (C) 1998-2002 David Baum.  All Rights Reserved.\n");
+	fprintf(STDERR,"     Copyright (C) 2005 John Hansen.  All Rights Reserved.\n");
 }
 
 void PrintUsage()
 {
 	PrintVersion();
 	fprintf(stdout,"Usage: nqc [options] [actions] [ - | filename ] [actions]\n");
-	fprintf(stdout,"   - : read from stdin instead of a source_file\n");	
-	fprintf(stdout,"Options:\n");	
-	fprintf(stdout,"   -1: use NQC 1.x compatability mode\n");	
-	fprintf(stdout,"   -T<target>: target can be RCX, CM, Scout, RCX2, or Spy\n");	
+	fprintf(stdout,"   - : read from stdin instead of a source_file\n");
+	fprintf(stdout,"Options:\n");
+	fprintf(stdout,"   -T<target>: target can be RCX, CM, Scout, RCX2, Spy, or Swan\n");
 	fprintf(stdout,"   -d: download program\n");
 	fprintf(stdout,"   -n: prevent the system file (rcx.nqh) from being included\n");
-	fprintf(stdout,"   -b: treat input file as a binary file (don't compile it)\n");	
+	fprintf(stdout,"   -b: treat input file as a binary file (don't compile it)\n");
 	fprintf(stdout,"   -D<sym>[=<value>] : define macro <sym>\n");
 	fprintf(stdout,"   -E[<filename>] : write compiler errors to <filename> (or stdout)\n");
 	fprintf(stdout,"   -R<filename> : redirect text output (datalog, etc) to <filename>\n");
 	fprintf(stdout,"   -I<path>: search <path> for include files\n");
 	fprintf(stdout,"   -L[<filename>] : generate code listing to <filename> (or stdout)\n");
-	fprintf(stdout,"   -s : include source code in listings if possible\n");
+	fprintf(stdout,"   -s: include source code in listings if possible\n");
+	fprintf(stdout,"   -c: generate LASM compatible listings\n");
+	fprintf(stdout,"   -v: verbose\n");
+	fprintf(stdout,"   -q: quiet\n");
+	fprintf(stdout,"   -x: omit packet header (RCX only)\n");
+	fprintf(stdout,"   -f<size>: set firmware chunk size\n");
+	fprintf(stdout,"   -w<ms>: set the download wait timeout\n");
+//	fprintf(stdout,"   -p<size>: set program chunk size\n");
+//	fprintf(stdout,"   -X<factor>: set USB tower speed factor (<100=faster, >100=slower)\n");
 	fprintf(stdout,"   -O<outfile>: specify output file\n");
 	fprintf(stdout,"   -S<portname>: specify serial port\n");
 	fprintf(stdout,"   -U<sym>: undefine macro <sym>\n");
-	fprintf(stdout,"Actions:\n");	
+	fprintf(stdout,"Actions:\n");
 	fprintf(stdout,"   -run: run current program\n");
 	fprintf(stdout,"   -pgm <number>: select program number\n");
 	fprintf(stdout,"   -datalog | -datalog_full: upload datalog\n");
-	fprintf(stdout,"   -near : set IR to near mode\n");
-	fprintf(stdout,"   -far : set IR to far mode\n");
-	fprintf(stdout,"   -watch <time> | now : set RCX time\n");
-	fprintf(stdout,"   -firmware <filename> : download firmware\n");
-	fprintf(stdout,"   -firmfast <filename> : download firmware at quad speed\n");
-	fprintf(stdout,"   -sleep <timeout> : set RCX sleep timeout\n");
-	fprintf(stdout,"   -msg <number> : send IR message to RCX\n");
-	fprintf(stdout,"   -raw <data> : format data as a packet and send to RCX\n");
-	fprintf(stdout,"   -remote <value> <repeat> : send a remote command to the RCX\n");
-	fprintf(stdout,"   -clear : erase all programs and datalog in RCX\n");
-	fprintf(stdout,"   -api : dump the standard api file (e.g. rcx.nqh) to stdout\n");
-	fprintf(stdout,"   -help : display command line options\n");
+	fprintf(stdout,"   -near: set IR to near mode\n");
+	fprintf(stdout,"   -far: set IR to far mode\n");
+	fprintf(stdout,"   -watch <time> | now: set RCX time\n");
+	fprintf(stdout,"   -firmware <filename>: download firmware\n");
+	fprintf(stdout,"   -firmfast <filename>: download firmware at quad speed\n");
+	fprintf(stdout,"   -sleep <timeout>: set RCX sleep timeout\n");
+	fprintf(stdout,"   -msg <number>: send IR message to RCX\n");
+	fprintf(stdout,"   -raw <data>: format data as a packet and send to RCX\n");
+	fprintf(stdout,"   -remote <value> <repeat>: send a remote command to the RCX\n");
+	fprintf(stdout,"   -clear: erase all programs and datalog in RCX\n");
+	fprintf(stdout,"   -api: dump the standard api file (e.g. rcx.nqh) to stdout\n");
+	fprintf(stdout,"   -help: display command line options\n");
 }
 
 
 RCX_Result AutoLink::Open()
 {
 	RCX_Result result;
-	
+
 	if (!fOpen)
 	{
 		ULong options = gTimeout & RCX_Link::kRxTimeoutMask;
 		if (gVerbose) options |= RCX_Link::kVerboseMode;
-		
+
 		result = RCX_Link::Open(gTargetType, fSerialPort, options);
 		if (RCX_ERROR(result)) return result;
-		
+
 		fOpen = true;
 	}
 	return kRCX_OK;
@@ -1121,10 +1167,10 @@ void AutoLink::Close()
 RCX_Result AutoLink::Send(const RCX_Cmd *cmd, bool retry)
 {
 	RCX_Result result;
-	
+
 	result = Open();
 	if (RCX_ERROR(result)) return result;
-	
+
 	if (retry)
 	{
 		result = Sync();
@@ -1160,7 +1206,7 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 			return;
 		}
 	}
-	
+
 	char msg[Error::kMaxErrorMsg];
 	e.SPrint(msg);
 
@@ -1169,12 +1215,12 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 
 	if (loc && loc->fIndex!=kIllegalSrcIndex)
 	{
-		Buffer *b = Compiler::Get()->GetBuffer(loc->fIndex);	
+		Buffer *b = Compiler::Get()->GetBuffer(loc->fIndex);
 		int lineStart = loc->fOffset;
 		int line = b->FindLine(lineStart);
 		const char *ptr;
 		int i;
-		
+
 		// print file/line info
 		fprintf(gErrorStream, "File \"%s\" ; line %d\n", b->GetName(), line);
 
@@ -1184,7 +1230,7 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 		{
 			putc((*ptr == '\t') ? ' ' : *ptr, gErrorStream);
 		}
-		
+
 		// mark the token
 		fprintf(gErrorStream,"\n# ");
 		for(i=0; i<(loc->fOffset-lineStart); i++)
@@ -1203,13 +1249,13 @@ void MyCompiler::AddError(const Error &e, const LexLocation *loc)
 
 Buffer *MyCompiler::CreateBuffer(const char *name)
 {
-	static char pathname[DirList::kMaxPathname];	
+	static char pathname[DirList::kMaxPathname];
 
 	if (!fDirs.Find(name, pathname))
 		return nil;
 
 	Buffer *buf = new Buffer();
-	
+
 	if (buf->Create(name, pathname))
 		return buf;
 	else
@@ -1220,6 +1266,7 @@ Buffer *MyCompiler::CreateBuffer(const char *name)
 }
 
 
+#ifdef TEST_LEXER
 void PrintToken(int t, TokenVal v)
 {
 	printf("%3d / ", t);
@@ -1243,22 +1290,23 @@ void PrintToken(int t, TokenVal v)
 			printf("0x%08x", v.fInt);
 			break;
 	}
-	
+
 	printf("\n");
 }
+#endif
 
 
 bool SameString(const char *s1, const char *s2)
 {
 	char c1, c2;
-	
+
 	while(true)
 	{
 		c1 = *s1++;
 		c2 = *s2++;
-		
+
 		if (c1==0 && c2==0) return true;
-		
+
 		if (tolower(c1) != tolower(c2)) return false;
 	}
 }
