@@ -12,11 +12,15 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifdef PDEBUG
 
-#include <stdio.h>
+#include <cstdio>
 #include "PDebug.h"
 
 static const char *get_leafname(const char *filename);
@@ -40,7 +44,7 @@ void _p_require(const char* file, int line, const char* label)
 
 
 void _p_requirenot(const char* file, int line, int val, const char* label)
-{ 
+{
 	char buffer[512];
 	sprintf(buffer, "PREQUIRENOT %s failed line #%d in file %s, value = %d",
 		label, line, get_leafname(file), val);
@@ -53,7 +57,7 @@ const char *get_leafname(const char *filename)
 {
 	const char *leaf = filename;
 	const char *ptr = filename;
-	
+
 	while(*ptr != 0)
 	{
 		if (*ptr == ':')
