@@ -20,14 +20,14 @@
  * does not support changing the baud rate or other attributes.  It does
  * now support manual control of RTS and DTR lines.
  */
- 
+
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <sys/ioctl.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <string.h>
+#include <cstring>
 #include <termios.h>
 
 // need another #include for Solaris - Richard Mitchell <gpsphoto@designprofessionals.com>
@@ -45,7 +45,7 @@
 class PSerial_unix : public PSerial
 {
 public:
-					PSerial_unix(void);
+			PSerial_unix(void);
 	virtual	bool	Open(const char *name);
 	virtual void	Close();
 	virtual long	Write(const void *ptr, long count);
@@ -61,7 +61,7 @@ public:
 private:
 	bool	SetRaw(void);
 	bool	SetLineData(int bits, bool state);
-	  
+
 	int		fTerm;
 	long	fTimeout;
     bool	fUseTcDrain;
@@ -96,9 +96,9 @@ bool PSerial_unix::Open(const char *name)
 {
     bool ok;
     char *buf = 0;
-    
+
     fUseTcDrain = true;
-    
+
     // check for option
     const char *ptr = (const char *)strchr(name, ':');
     if (ptr)
@@ -113,8 +113,8 @@ bool PSerial_unix::Open(const char *name)
             fUseTcDrain = false;
         }
         name = buf;
-    }    
-    
+    }
+
     ok = ((fTerm = open(name, O_RDWR)) >= 0);
     if (ok)
     {
@@ -163,7 +163,7 @@ bool PSerial_unix::SetRaw(void)
 
 
 	SetSpeed(9600, 0);
-	
+
 	return true;
 }
 
@@ -181,14 +181,14 @@ void PSerial_unix::Close()
 bool PSerial_unix::SetSpeed(int speed, int opts)
 {
 	termios tios;
-	
+
 	if (tcgetattr(fTerm, &tios) < 0)
 		return false;
 
 	// set the speed
 	if (!SetTermiosSpeed(tios, speed))
 		return false;
-	
+
 	// set the parity
 	switch(opts & kPSerial_ParityMask)
 	{
@@ -203,7 +203,7 @@ bool PSerial_unix::SetSpeed(int speed, int opts)
 			tios.c_cflag &= ~(PARODD);
 			break;
 	};
-	
+
 	if (tcsetattr(fTerm, TCSAFLUSH, &tios) < 0)
 		return false;
 
@@ -216,7 +216,7 @@ long PSerial_unix::Write(const void *ptr, long count)
 	return write(fTerm, ptr, count);
 }
 
-#include <stdio.h>
+#include <cstdio>
 void PSerial_unix::FlushWrite()
 {
 #ifndef NO_TCDRAIN
@@ -269,13 +269,13 @@ long PSerial_unix::Read(void *ptr, long count)
 		{
 			return -1;
 		}
-		
+
 		if (tv_ge(&delay, &expire))
 		{
 			// delay (current time) >= expire
 		  	break;
 		}
-		
+
 		tv_sub(&expire, &delay);	// delay = expire - delay
 
 		if (select(fTerm + 1, &rfds, NULL, NULL, &delay))
@@ -284,7 +284,7 @@ long PSerial_unix::Read(void *ptr, long count)
 			{
 				return -1;
 		  	}
-		  	
+
 		  	nread = (count < nread) ? count : nread;
 		  	if ((nread = read(fTerm, cur, nread)) < 0)
 		  	{
@@ -327,7 +327,7 @@ bool PSerial_unix::SetLineData(int bits, bool state)
 	if (ioctl(fTerm, TIOCMGET, &lineData))
 	{
 		return false;
-	} 
+	}
 	else
 	{
 		if (state)
@@ -347,7 +347,7 @@ bool PSerial_unix::SetLineData(int bits, bool state)
 bool SetTermiosSpeed(termios &tios, int speed)
 {
 	speed_t s;
-	
+
 	switch(speed)
 	{
 		case 2400:
@@ -362,10 +362,10 @@ bool SetTermiosSpeed(termios &tios, int speed)
 		default:
 			return false;
 	}
-	
+
 	if (cfsetispeed(&tios, s) < 0)
 		return false;
-	
+
 	if (cfsetospeed(&tios, s) < 0)
 		return false;
 
