@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __RCX_Target_h
@@ -27,7 +31,8 @@ typedef enum
 	kRCX_CMTarget,		// CyberMaster
 	kRCX_ScoutTarget,	// Scout
 	kRCX_RCX2Target,	// RCX 2.0
-	kRCX_SpyboticsTarget	// Spybotics
+	kRCX_SpyboticsTarget,	// Spybotics
+        kRCX_SwanTarget         // Dick Swan's alternate firmware
 } RCX_TargetType;
 
 
@@ -38,23 +43,25 @@ public:
 		int	fBase;
 		int	fCount;
 	};
-	
+
 	RCX_TargetType	fType;
-	const char*		fName;
-	const char*		fDefine;
-	const char*		fDefValue;
-	
-	Range			fRanges[kRCX_ChunkTypeCount];
-	
-	int				fMaxGlobalVars;
-	int				fMaxTaskVars;
-	bool			fResources;
-	bool			fEvents;
-	bool			fArrays;
-	bool			fRestrictedMath;
-	
-	bool			SourceWritable(int source) const;
-	int				GetChunkLimit(RCX_ChunkType type) const;
+	const char*	fName;
+	const char*	fDefine;
+	const char*	fDefValue;
+
+	Range		fRanges[kRCX_ChunkTypeCount];
+
+	int		fMaxGlobalVars;
+	int		fMaxTaskVars;
+	bool		fResources;
+	bool		fEvents;
+	bool		fArrays;
+        bool		fRestrictedMath;
+        bool		fSubParams;
+        bool		fHasExtendedMathOps;
+
+	bool		SourceWritable(int source) const;
+	int		GetChunkLimit(RCX_ChunkType type) const;
 };
 
 
