@@ -12,16 +12,23 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
-#include <stdio.h>
+#include <cstdio>
 #include "RCX_Transport.h"
 #include "RCX_Target.h"
 
+using std::printf;
+using std::putchar;
+
 void RCX_Transport::DumpData(const UByte *ptr, int length)
 {
 	int i;
-	
+
 	for(i=0; i<length; i++)
 	{
 		printf("%02x ", *ptr++);
