@@ -12,6 +12,10 @@
  * The Initial Developer of this code is David Baum.
  * Portions created by David Baum are Copyright (C) 1998 David Baum.
  * All Rights Reserved.
+ *
+ * Portions created by John Hansen are Copyright (C) 2005 John Hansen.
+ * All Rights Reserved.
+ *
  */
 
 #ifndef __RCX_Transport_h
@@ -37,20 +41,24 @@
 class RCX_Transport
 {
 public:
-				RCX_Transport() {}
+			RCX_Transport() {}
 	virtual		~RCX_Transport() {};
 
 	virtual RCX_Result 	Open(RCX_TargetType target, const char *deviceName, ULong options) = 0;
 	virtual void		Close() = 0;
-	
-	virtual RCX_Result	Send(const UByte *txData, int txLength, UByte *rxData, int rxExpected, int rxMax, bool retry) = 0;
 
-	virtual bool		FastModeSupported()	 const { return false; }
+	virtual RCX_Result	Send(const UByte *txData, int txLength, UByte *rxData, int rxExpected, int rxMax, bool retry, int timeout) = 0;
+
+	virtual bool		FastModeSupported() const { return false; }
 	virtual bool		FastModeOddParity() const { return false; }
 	virtual void		SetFastMode(bool /* fast */) { }
-	
+        virtual bool            GetFastMode() const { return false; }
+        void                    SetOmitHeader(bool value) { fOmitHeader = value; }
+        virtual bool            GetComplementData() const { return false; }
+
 protected:
-	static void DumpData(const UByte *ptr, int length);
+        static void DumpData(const UByte *ptr, int length);
+        bool fOmitHeader;
 
 private:
 };
