@@ -1,4 +1,4 @@
-#include <stdio.h>
+#include <cstdio>
 #include "RCX_Disasm.h"
 #include "RCX_Pipe.h"
 #include "RCX_PipeTransport.h"
@@ -9,23 +9,23 @@ class Reader
 public:
 			Reader();
 			~Reader();
-	
+
 	bool 	open(const char *name);
 	void	close();
 
 	void	poll();
-	
+
 	void	beginDownload();
 	void	continueDownload();
-	
+
 private:
 	static const int MAX_PACKET = 1024;
-	
+
 	RCX_PipeTransport*	transport;
-	
+
 	UByte		packet[MAX_PACKET];
 	int			packetLength;
-	
+
 	UByte*		code;
 	ULong		codeLength;
 	ULong		codePos;
@@ -46,14 +46,14 @@ Reader::~Reader()
 bool Reader::open(const char *name)
 {
 	RCX_Pipe *pipe = RCX_NewUSBTowerPipe();
-	transport = new RCX_PipeTransport(pipe);	
-	
+	transport = new RCX_PipeTransport(pipe);
+
 	if (transport->Open(kRCX_RCX2Target, name, RCX_Link::kVerboseMode) != kRCX_OK) {
 		delete transport;
 		transport = 0;
 		return false;
 	}
-	
+
 	return true;
 }
 
@@ -78,13 +78,13 @@ int main(int, char **)
 		printf("Error opening USB IR tower\n");
 		return -1;
 	}
-	
+
 	while(1) {
 		reader.poll();
 	}
 
 	reader.close();
-	
+
 	return 0;
 }
 
@@ -93,11 +93,11 @@ void Reader::poll()
 {
 	RCX_Result r = transport->Receive(packet, MAX_PACKET, false);
 	if (r <= 0) return;
-	
+
 	UByte cmd = packet[0];
 	UByte data[9];
 	UByte *ptr = data;
-	
+
 	*ptr++ = ~cmd;
 
 	cmd &= 0xf7;
@@ -120,7 +120,7 @@ void Reader::poll()
 			break;
 		case 0x45:	// continue download
 			continueDownload();
-			*ptr++ = 0; 
+			*ptr++ = 0;
 			break;
 		case 0x30:	// battery level
 			*ptr++ = 35;
@@ -137,11 +137,11 @@ void Reader::poll()
 
 void Reader::beginDownload()
 {
-	UByte number = packet[2];	
+	UByte number = packet[2];
 	codeLength = packet[4] + ((ULong)packet[5] << 8);
-	
+
 	delete [] code;
-	
+
 	code = new UByte[codeLength];
 	codePos = 0;
 	lastBlock = -1;
@@ -152,11 +152,11 @@ void Reader::continueDownload()
 {
 	ULong block = packet[1] + ((ULong)packet[2] << 8);
 	ULong length = packet[3] + ((ULong)packet[4] << 8);
-	
+
 	if (block == lastBlock) return;
-	
+
 	lastBlock = block;
-	
+
 	for(int i=0; i<length && codePos < codeLength; ++i)
 		code[codePos++] = packet[5 + i];
 
